@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 #
-# Copyright (C) 2002-2018 John W. Eaton
+# Copyright (C) 2002-2019 John W. Eaton
 #
 # This file is part of Octave.
 #
@@ -512,7 +512,8 @@ sub emit_opt_handler_fcns
 // this file.
 
 #include <iomanip>
-#include <iostream>
+#include <ostream>
+#include <sstream>
 
 #include "$header"
 
@@ -745,7 +746,7 @@ set_$CLASS_NAME (const std::string& keyword, const octave_value& val)
     {
       $iftok = "else if" if ($i > 0);
 
-      print "  $iftok (keyword_almost_match (list[$i].kw_tok, list[$i].min_len,
+      print "  $iftok (octave::keyword_almost_match (list[$i].kw_tok, list[$i].min_len,
            keyword, list[$i].min_toks_to_match, MAX_TOKENS))
     {\n";
 
@@ -814,7 +815,7 @@ show_$CLASS_NAME (const std::string& keyword)
     {
       $iftok = "else if" if ($i > 0);
 
-      print "  $iftok (keyword_almost_match (list[$i].kw_tok, list[$i].min_len,
+      print "  $iftok (octave::keyword_almost_match (list[$i].kw_tok, list[$i].min_len,
            keyword, list[$i].min_toks_to_match, MAX_TOKENS))
     {\n";
 
