@@ -1,20 +1,22 @@
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} FIRfilter ()
-## @deftypefnx {Function File} {} FIRfilter (@var{p})
+## @deftypefn  {} {} FIRfilter ()
+## @deftypefnx {} {} FIRfilter (@var{p})
 ## Create a FIR filter with polynomial @var{p} as coefficient vector.
 ## @end deftypefn
 
 function f = FIRfilter (p)
 
-  f.polynomial = [];
-  if (nargin == 0)
-    p = @polynomial ([1]);
-  elseif (nargin == 1)
-    if (!isa (p, "polynomial"))
-      error ("FIRfilter: expecting polynomial as input argument");
-    endif
-  else
+  if (nargin > 1)
     print_usage ();
   endif
+
+  if (nargin == 0)
+    p = @polynomial ([1]);
+  elseif (! isa (p, "polynomial"))
+    error ("@FIRfilter: P must be a polynomial object");
+  endif
+
+  f.polynomial = [];
   f = class (f, "FIRfilter", p);
+
 endfunction
