@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 2011-2017 Michael Goffioul
+Copyright (C) 2011-2019 Michael Goffioul
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -37,7 +37,7 @@ namespace QtHandles
 {
 
   static void
-  updatePalette (const uicontrol::properties& props, QWidget* w)
+  updatePalette (const uicontrol::properties& props, QWidget *w)
   {
     QPalette p = w->palette ();
 
@@ -52,14 +52,13 @@ namespace QtHandles
     else if (props.style_is ("popupmenu"))
       {
         // popumenu (QComboBox) is a listbox with a button, so needs set colors for both
-        p.setColor (QPalette::Base,
-                    Utils::fromRgb (props.get_backgroundcolor_rgb ()));
-        p.setColor (QPalette::Text,
-                    Utils::fromRgb (props.get_foregroundcolor_rgb ()));
-        p.setColor (QPalette::Button,
-                    Utils::fromRgb (props.get_backgroundcolor_rgb ()));
-        p.setColor (QPalette::ButtonText,
-                    Utils::fromRgb (props.get_foregroundcolor_rgb ()));
+        QColor bcol = Utils::fromRgb (props.get_backgroundcolor_rgb ());
+        QColor fcol = Utils::fromRgb (props.get_foregroundcolor_rgb ());
+        QString qss = QString ("background: %1 none;\n"
+                               "color: %2;")
+                      .arg(bcol.name ()).arg (fcol.name ());
+        w->setStyleSheet(qss);
+        return;
       }
     else if (props.style_is ("radiobutton")
              || props.style_is ("checkbox"))
@@ -72,10 +71,13 @@ namespace QtHandles
     else if (props.style_is ("pushbutton")
              || props.style_is ("togglebutton"))
       {
-        p.setColor (QPalette::Button,
-                    Utils::fromRgb (props.get_backgroundcolor_rgb ()));
-        p.setColor (QPalette::ButtonText,
-                    Utils::fromRgb (props.get_foregroundcolor_rgb ()));
+        QColor bcol = Utils::fromRgb (props.get_backgroundcolor_rgb ());
+        QColor fcol = Utils::fromRgb (props.get_foregroundcolor_rgb ());
+        QString qss = QString ("background: %1 none;\n"
+                               "color: %2;")
+                      .arg(bcol.name ()).arg (fcol.name ());
+        w->setStyleSheet(qss);
+        return;
       }
     else
       {
@@ -88,14 +90,14 @@ namespace QtHandles
     w->setPalette (p);
   }
 
-  BaseControl::BaseControl (const graphics_object& go, QWidget* w)
+  BaseControl::BaseControl (const graphics_object& go, QWidget *w)
     : Object (go, w), m_normalizedFont (false), m_keyPressHandlerDefined (false)
   {
     init (w);
   }
 
   void
-  BaseControl::init (QWidget* w, bool callBase)
+  BaseControl::init (QWidget *w, bool callBase)
   {
     if (callBase)
       Object::init (w, callBase);
@@ -110,7 +112,7 @@ namespace QtHandles
     w->setEnabled (up.enable_is ("on"));
     w->setToolTip (Utils::fromStdString (up.get_tooltipstring ()));
     w->setVisible (up.is_visible ());
-    m_keyPressHandlerDefined = ! up.get_keypressfcn ().is_empty ();
+    m_keyPressHandlerDefined = ! up.get_keypressfcn ().isempty ();
 
     w->installEventFilter (this);
 
@@ -124,7 +126,7 @@ namespace QtHandles
   BaseControl::update (int pId)
   {
     uicontrol::properties& up = properties<uicontrol> ();
-    QWidget* w = qWidget<QWidget> ();
+    QWidget *w = qWidget<QWidget> ();
 
     switch (pId)
       {
@@ -168,7 +170,14 @@ namespace QtHandles
         break;
 
       case uicontrol::properties::ID_KEYPRESSFCN:
-        m_keyPressHandlerDefined = ! up.get_keypressfcn ().is_empty ();
+        m_keyPressHandlerDefined = ! up.get_keypressfcn ().isempty ();
+        break;
+
+      case uicontrol::properties::ID___FOCUS__:
+        if (up.is___focus__ ())
+          w->setFocus ();
+        else
+          w->clearFocus ();
         break;
 
       default:
@@ -177,7 +186,7 @@ namespace QtHandles
   }
 
   bool
-  BaseControl::eventFilter (QObject* watched, QEvent* xevent)
+  BaseControl::eventFilter (QObject *watched, QEvent *xevent)
   {
     switch (xevent->type ())
       {
@@ -195,34 +204,39 @@ namespace QtHandles
         {
           gh_manager::auto_lock lock;
 
-          QMouseEvent* m = dynamic_cast<QMouseEvent*> (xevent);
+          QMouseEvent *m = dynamic_cast<QMouseEvent *> (xevent);
           graphics_object go = object ();
           uicontrol::properties& up = Utils::properties<uicontrol> (go);
           graphics_object fig = go.get_ancestor ("figure");
-
-          if (m->button () != Qt::LeftButton
-              || ! up.enable_is ("on"))
+          if (fig)
             {
-              gh_manager::post_set (fig.get_handle (), "selectiontype",
-                                    Utils::figureSelectionType (m), false);
-              gh_manager::post_set (fig.get_handle (), "currentpoint",
-                                    Utils::figureCurrentPoint (fig, m),
-                                    false);
-              gh_manager::post_callback (fig.get_handle (),
-                                         "windowbuttondownfcn");
-              gh_manager::post_callback (m_handle, "buttondownfcn");
+              gh_manager::post_set (fig.get_handle (), "currentobject",
+                                    m_handle.value (), false);
 
-              if (m->button () == Qt::RightButton)
-                ContextMenu::executeAt (up, m->globalPos ());
-            }
-          else
-            {
-              if (up.style_is ("listbox"))
-                gh_manager::post_set (fig.get_handle (), "selectiontype",
-                                      Utils::figureSelectionType (m), false);
+              if (m->button () != Qt::LeftButton || ! up.enable_is ("on"))
+                {
+                  gh_manager::post_set (fig.get_handle (), "selectiontype",
+                                        Utils::figureSelectionType (m), false);
+                  gh_manager::post_set (fig.get_handle (), "currentpoint",
+                                        Utils::figureCurrentPoint (fig, m),
+                                        false);
+                  gh_manager::post_callback (fig.get_handle (),
+                                             "windowbuttondownfcn");
+                  gh_manager::post_callback (m_handle, "buttondownfcn");
+
+                  if (m->button () == Qt::RightButton)
+                    ContextMenu::executeAt (up, m->globalPos ());
+                }
               else
-                gh_manager::post_set (fig.get_handle (), "selectiontype",
-                                      octave_value ("normal"), false);
+                {
+                  if (up.style_is ("listbox"))
+                    gh_manager::post_set (fig.get_handle (), "selectiontype",
+                                          Utils::figureSelectionType (m),
+                                          false);
+                  else
+                    gh_manager::post_set (fig.get_handle (), "selectiontype",
+                                          octave_value ("normal"), false);
+                }
             }
         }
         break;
@@ -232,13 +246,17 @@ namespace QtHandles
           {
             gh_manager::auto_lock lock;
 
-            QMouseEvent* m = dynamic_cast<QMouseEvent*> (xevent);
+            QMouseEvent *m = dynamic_cast<QMouseEvent *> (xevent);
             graphics_object go = object ();
             graphics_object fig = go.get_ancestor ("figure");
 
-            gh_manager::post_set (fig.get_handle (), "currentpoint",
-                                  Utils::figureCurrentPoint (fig, m), false);
-            gh_manager::post_callback (fig.get_handle (), "windowbuttonmotionfcn");
+            if (fig)
+              {
+                gh_manager::post_set (fig.get_handle (), "currentpoint",
+                                      Utils::figureCurrentPoint (fig, m), false);
+                gh_manager::post_callback (fig.get_handle (),
+                                           "windowbuttonmotionfcn");
+              }
           }
         break;
 
@@ -248,7 +266,7 @@ namespace QtHandles
             gh_manager::auto_lock lock;
 
             octave_scalar_map keyData =
-              Utils::makeKeyEventStruct (dynamic_cast<QKeyEvent*> (xevent));
+              Utils::makeKeyEventStruct (dynamic_cast<QKeyEvent *> (xevent));
             graphics_object fig = object ().get_ancestor ("figure");
 
             gh_manager::post_set (fig.get_handle (), "currentcharacter",
@@ -257,6 +275,14 @@ namespace QtHandles
           }
         break;
 
+      case QEvent::FocusIn:
+        gh_manager::post_set (m_handle, "__focus__", "on", false);
+        break;
+
+      case QEvent::FocusOut:
+        gh_manager::post_set (m_handle, "__focus__", "off", false);
+        break;
+
       default:
         break;
       }
