@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2011-2018 Michael Goffioul
+Copyright (C) 2011-2019 Michael Goffioul
 
 This file is part of Octave.
 
@@ -81,6 +81,7 @@ namespace QtHandles
     void slotUpdate (int pId);
     void slotFinalize (void);
     void slotRedraw (void);
+    void slotShow (void);
     void slotPrint (const QString& file_cmd, const QString& term);
 
     void objectDestroyed (QObject *obj = nullptr);
@@ -92,6 +93,7 @@ namespace QtHandles
     virtual void update (int pId);
     virtual void finalize (void);
     virtual void redraw (void);
+    virtual void show (void);
     virtual void print (const QString& file_cmd, const QString& term);
 
     virtual void beingDeleted (void);
