@@ -3,9 +3,9 @@
     Copyright (C) 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
 
     Rewritten for QT4 by e_k <e_k at users.sourceforge.net>, Copyright (C)2008
-    Copyright (C) 2012-2015 Jacob Dawid <jacob.dawid@cybercatalyst.com>
+    Copyright (C) 2012-2019 Jacob Dawid <jacob.dawid@cybercatalyst.com>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
@@ -66,7 +66,7 @@ class TerminalView : public QWidget
 
 public:
     /** Constructs a new terminal display widget with the specified parent. */
-    TerminalView(QWidget *parent = 0);
+    TerminalView(QWidget *parent = nullptr);
     virtual ~TerminalView();
 
     /** Returns the terminal color palette used by the display. */
@@ -124,22 +124,6 @@ public:
      */
     FilterChain* filterChain() const;
 
-    /**
-     * Updates the filters in the display's filter chain.  This will cause
-     * the hotspots to be updated to match the current image.
-     *
-     * WARNING:  This function can be expensive depending on the
-     * image size and number of filters in the filterChain()
-     *
-     * TODO - This API does not really allow efficient usage.  Revise it so
-     * that the processing can be done in a better way.
-     *
-     * eg:
-     *      - Area of interest may be known ( eg. mouse cursor hovering
-     *      over an area )
-     */
-    void processFilters();
-
     /**
      * Returns a list of menu actions created by the filters for the content
      * at the given @p position.
@@ -390,8 +374,29 @@ public:
     /** Returns the terminal screen section which is displayed in this widget.  See setScreenWindow() */
     ScreenWindow* screenWindow() const;
 
+    /** Is called, when the terminal's visibility has changed in order to
+     *  stop orstart timers etc.
+     */
+    void visibility_changed (bool visible);
+
 public slots:
 
+    /**
+     * Updates the filters in the display's filter chain.  This will cause
+     * the hotspots to be updated to match the current image.
+     *
+     * WARNING:  This function can be expensive depending on the
+     * image size and number of filters in the filterChain()
+     *
+     * TODO - This API does not really allow efficient usage.  Revise it so
+     * that the processing can be done in a better way.
+     *
+     * eg:
+     *      - Area of interest may be known ( eg. mouse cursor hovering
+     *      over an area )
+     */
+    void processFilters();
+
     /**
      * Causes the terminal display to fetch the latest character image from the associated
      * terminal screen ( see setScreenWindow() ) and redraw the display.
@@ -686,6 +691,7 @@ private:
     bool _isFixedSize; //Columns / lines are locked.
     QTimer* _blinkTimer;  // active when hasBlinker
     QTimer* _blinkCursorTimer;  // active when hasBlinkingCursor
+    QTimer* _process_filter_timer;  // active when visible, filter processing
 
 //    KMenu* _drop;
     QString _dropText;
