@@ -793,7 +793,7 @@ nevermind:
 %! y = true;
 %! A = cellfun (@(x) islogical (x) && y, {false, 0.3});
 %! assert (A, [true, false]);
-%!test  # Three ouptut arguments of different type
+%!test  # Three output arguments of different type
 %! [A, B, C] = cellfun (@find, {10, 11; 0, 12}, "UniformOutput", false);
 %! assert (isequal (A, {true, true; [], true}));
 %! assert (isequal (B, {true, true; [], true}));
@@ -810,7 +810,7 @@ nevermind:
 %!test
 %! A = cellfun (@(x) x, {false, true; false, true}, "UniformOutput", false);
 %! assert (A, {false, true; false, true});
-%!test  # Three ouptut arguments of same type
+%!test  # Three output arguments of same type
 %! [A, B, C] = cellfun (@find, {true, false; false, true}, ...
 %!                      "UniformOutput", false);
 %! assert (isequal (A, {true, []; [], true}));
@@ -845,7 +845,7 @@ nevermind:
 %! A = cellfun (@(x,y) x:y, {1.1, 4}, {3.1, 6}, "UniformOutput", false);
 %! assert (isequal (A{1}, [1.1, 2.1, 3.1]));
 %! assert (isequal (A{2}, [4, 5, 6]));
-%!test  # Three ouptut arguments of different type
+%!test  # Three output arguments of different type
 %! [A, B, C] = cellfun (@find, {10, 11; 0, 12}, "UniformOutput", false);
 %! assert (isequal (A, {true, true; [], true}));
 %! assert (isequal (B, {true, true; [], true}));
@@ -1476,7 +1476,7 @@ arrayfun (@@str2num, [1234],
 %! y = true;
 %! A = arrayfun (@(x) islogical (x && y), false);
 %! assert (A, true);
-%!test  # Three ouptut arguments of different type
+%!test  # Three output arguments of different type
 %! [A, B, C] = arrayfun (@find, [10, 11; 0, 12], "UniformOutput", false);
 %! assert (isequal (A, {true, true; [], true}));
 %! assert (isequal (B, {true, true; [], true}));
@@ -1492,7 +1492,7 @@ arrayfun (@@str2num, [1234],
 %!test
 %! A = arrayfun (@(x) x, [false, true, false, true], "UniformOutput", false);
 %! assert (A, {false, true, false, true});
-%!test  # Three ouptut arguments of same type
+%!test  # Three output arguments of same type
 %! [A, B, C] = arrayfun (@find, [true, false; false, true], "UniformOutput", false);
 %! assert (isequal (A, {true, []; [], true}));
 %! assert (isequal (B, {true, []; [], true}));
@@ -1525,7 +1525,7 @@ arrayfun (@@str2num, [1234],
 %! A = arrayfun (@(x,y) x:y, [1.1, 4], [3.1, 6], "UniformOutput", false);
 %! assert (isequal (A{1}, [1.1, 2.1, 3.1]));
 %! assert (isequal (A{2}, [4, 5, 6]));
-%!test  # Three ouptut arguments of different type
+%!test  # Three output arguments of different type
 %! [A, B, C] = arrayfun (@find, [10, 11; 0, 12], "UniformOutput", false);
 %! assert (isequal (A, {true, true; [], true}));
 %! assert (isequal (B, {true, true; [], true}));
@@ -2118,7 +2118,7 @@ Each dimension argument (@var{dim1}, @var{dim2}, etc.@:) is a vector of
 integers which specifies how to divide that dimension's elements amongst the
 new elements in the output @var{C}.  The number of elements in the @var{i}-th
 dimension is @code{size (@var{A}, @var{i})}.  Because all elements in @var{A}
-must be partitioned, there is a requirement that @code{sum (@var{di}) == size
+must be partitioned, there is a requirement that @code{sum (@var{dimi}) == size
 (@var{A}, i)}.  The size of the output cell @var{C} is numel (@var{dim1}) x
 numel (@var{dim2}) x @dots{} x numel (@var{dimn}).
 
