@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1997-2018 David Bateman
+Copyright (C) 1997-2019 David Bateman
 Copyright (C) 1996-1997 John W. Eaton
 
 This file is part of Octave.
@@ -33,12 +33,6 @@ along with Octave; see the file COPYING.  If not, see
 #include "ovl.h"
 #include "utils.h"
 
-#if defined (HAVE_FFTW)
-#  define FFTSRC "@sc{fftw}"
-#else
-#  define FFTSRC "@sc{fftpack}"
-#endif
-
 static octave_value
 do_fft (const octave_value_list& args, const char *fcn, int type)
 {
@@ -161,21 +155,35 @@ do_fft (const octave_value_list& args, const char *fcn, int type)
 }
 
 /*
-%!assert (fft ([]), [])
-%!assert (fft (zeros (10,0)), zeros (10,0))
-%!assert (fft (zeros (0,10)), zeros (0,10))
-%!assert (fft (0), 0)
-%!assert (fft (1), 1)
-%!assert (fft (ones (2,2)), [2,2; 0,0])
-%!assert (fft (eye (2,2)), [1,1; 1,-1])
+%!testif HAVE_FFTW
+%! assert (fft ([]), [])
+%!testif HAVE_FFTW
+%! assert (fft (zeros (10,0)), zeros (10,0))
+%!testif HAVE_FFTW
+%! assert (fft (zeros (0,10)), zeros (0,10))
+%!testif HAVE_FFTW
+%! assert (fft (0), 0)
+%!testif HAVE_FFTW
+%! assert (fft (1), 1)
+%!testif HAVE_FFTW
+%! assert (fft (ones (2,2)), [2,2; 0,0])
+%!testif HAVE_FFTW
+%! assert (fft (eye (2,2)), [1,1; 1,-1])
 
-%!assert (fft (single ([])), single ([]))
-%!assert (fft (zeros (10,0,"single")), zeros (10,0,"single"))
-%!assert (fft (zeros (0,10,"single")), zeros (0,10,"single"))
-%!assert (fft (single (0)), single (0))
-%!assert (fft (single (1)), single (1))
-%!assert (fft (ones (2,2,"single")), single ([2,2; 0,0]))
-%!assert (fft (eye (2,2,"single")), single ([1,1; 1,-1]))
+%!testif HAVE_FFTW
+%! assert (fft (single ([])), single ([]))
+%!testif HAVE_FFTW
+%! assert (fft (zeros (10,0,"single")), zeros (10,0,"single"))
+%!testif HAVE_FFTW
+%! assert (fft (zeros (0,10,"single")), zeros (0,10,"single"))
+%!testif HAVE_FFTW
+%! assert (fft (single (0)), single (0))
+%!testif HAVE_FFTW
+%! assert (fft (single (1)), single (1))
+%!testif HAVE_FFTW
+%! assert (fft (ones (2,2,"single")), single ([2,2; 0,0]))
+%!testif HAVE_FFTW
+%! assert (fft (eye (2,2,"single")), single ([1,1; 1,-1]))
 
 %!error (fft ())
 */
@@ -242,7 +250,7 @@ dimension of the matrix along which the inverse FFT is performed.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! N = 64;
 %! n = 4;
 %! t = 2*pi*(0:1:N-1)/N;
@@ -258,7 +266,7 @@ dimension of the matrix along which the inverse FFT is performed.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! N = 64;
 %! n = 7;
 %! t = 2*pi*(0:1:N-1)/N;
@@ -273,7 +281,7 @@ dimension of the matrix along which the inverse FFT is performed.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! N = 64;
 %! n = 4;
 %! t = single (2*pi*(0:1:N-1)/N);
@@ -289,7 +297,7 @@ dimension of the matrix along which the inverse FFT is performed.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! N = 64;
 %! n = 7;
 %! t = 2*pi*(0:1:N-1)/N;
