@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1993-2018 John W. Eaton
+Copyright (C) 1993-2019 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,7 +29,7 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <algorithm>
 #include <fstream>
-#include <iostream>
+#include <istream>
 #include <map>
 #include <sstream>
 #include <string>
@@ -37,6 +37,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "cmd-edit.h"
 #include "file-ops.h"
 #include "file-stat.h"
+#include "lo-sysdep.h"
 #include "oct-env.h"
 #include "oct-locbuf.h"
 #include "str-vec.h"
@@ -61,7 +62,6 @@ along with Octave; see the file COPYING.  If not, see
 #include "parse.h"
 #include "pathsearch.h"
 #include "procstream.h"
-#include "pt-pr-code.h"
 #include "quit.h"
 #include "sighandlers.h"
 #include "symtab.h"
@@ -237,14 +237,17 @@ namespace octave
   {
     std::string file;
 
+    if (name.empty ())
+      return file;
+
     type = "";
 
-    symbol_table& symtab = m_interpreter.get_symbol_table ();
-
-    octave_value val = symtab.find_function (name);
-
     if (name.find_first_of ('.') == std::string::npos)
       {
+        symbol_table& symtab = m_interpreter.get_symbol_table ();
+
+        octave_value val = symtab.find_function (name);
+
         if (val.is_defined ())
           {
             octave_function *fcn = val.function_value ();
@@ -554,7 +557,7 @@ namespace octave
   {
     bool retval = false;
 
-    h = octave::get_help_from_file (nm, symbol_found, file);
+    h = get_help_from_file (nm, symbol_found, file);
 
     if (h.length () > 0)
       retval = true;
@@ -582,7 +585,10 @@ namespace octave
 
     if (! initialized)
       {
-        std::ifstream file (m_built_in_docstrings_file.c_str (),
+        std::string ascii_fname
+          = octave::sys::get_ASCII_filename (m_built_in_docstrings_file);
+
+        std::ifstream file (ascii_fname.c_str (),
                             std::ios::in | std::ios::binary);
 
         if (! file)
@@ -627,7 +633,7 @@ namespace octave
             // skip newline characters
             while (file
                    && (c = file.get ()) != std::istream::traits_type::eof ()
-                   && c == '\n' && c == '\r')
+                   && (c == '\n' || c == '\r'))
               ; // skip text
 
             file.unget ();
@@ -665,7 +671,10 @@ namespace octave
         std::streampos beg = txt_limits.first;
         std::streamoff len = txt_limits.second;
 
-        std::ifstream file (m_built_in_docstrings_file.c_str (),
+        std::string ascii_fname
+          = octave::sys::get_ASCII_filename (m_built_in_docstrings_file);
+
+        std::ifstream file (ascii_fname.c_str (),
                             std::ios::in | std::ios::binary);
 
         if (! file)
@@ -693,8 +702,7 @@ namespace octave
 
   string_vector make_name_list (void)
   {
-    octave::help_system& help_sys
-      = octave::__get_help_system__ ("make_name_list");
+    help_system& help_sys = __get_help_system__ ("make_name_list");
 
     return help_sys.make_name_list ();
   }
@@ -705,9 +713,9 @@ DEFMETHOD (get_help_text, interp, args, ,
 @deftypefn {} {[@var{text}, @var{format}] =} get_help_text (@var{name})
 Return the raw help text of function @var{name}.
 
-The raw help text is returned in @var{text} and the format in @var{format}
-The format is a string which is one of @qcode{"texinfo"},
-@qcode{"html"}, or @qcode{"plain text"}.
+The raw help text is returned in @var{text} and the format in @var{format}.
+The format is a string which is one of @qcode{"texinfo"}, @qcode{"html"}, or
+@w{@qcode{"plain text"}}.
 @seealso{get_help_text_from_file}
 @end deftypefn */)
 {
@@ -730,9 +738,9 @@ DEFMETHOD (get_help_text_from_file, interp, args, ,
 @deftypefn {} {[@var{text}, @var{format}] =} get_help_text_from_file (@var{fname})
 Return the raw help text from the file @var{fname}.
 
-The raw help text is returned in @var{text} and the format in @var{format}
-The format is a string which is one of @qcode{"texinfo"},
-@qcode{"html"}, or @qcode{"plain text"}.
+The raw help text is returned in @var{text} and the format in @var{format}.
+The format is a string which is one of @qcode{"texinfo"}, @qcode{"html"}, or
+@w{@qcode{"plain text"}}.
 @seealso{get_help_text}
 @end deftypefn */)
 {
@@ -833,8 +841,9 @@ the return value is an empty cell array.
 
 /*
 %!test
+%! old_dir = cd (tempdir ());
 %! f = tempname (".", "oct_");
-%! fcn_name = f(3:end);
+%! [~, fcn_name] = fileparts (f);
 %! f = [f ".m"];
 %! unwind_protect
 %!   fid = fopen (f, "w+");
@@ -848,6 +857,7 @@ the return value is an empty cell array.
 %!   assert (d{2} (3), 6);
 %! unwind_protect_cleanup
 %!   unlink (f);
+%!   cd (old_dir);
 %! end_unwind_protect
 */
 
