@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 2009-2016 Benjamin Lindner
+Copyright (C) 2009-2019 Benjamin Lindner
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -26,7 +26,7 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "ls-ascii-helper.h"
 
-#include <iostream>
+#include <istream>
 #include <sstream>
 
 // Helper functions when reading from ascii files.
@@ -72,7 +72,7 @@ skip_until_newline (std::istream& is, bool keep_newline)
         }
       else
         {
-          // No newline charater peeked, so read it and proceed to next
+          // No newline character peeked, so read it and proceed to next
           // character.
           char d;
           is.get (d);
@@ -118,7 +118,7 @@ skip_preceeding_newline (std::istream& is)
     }
 }
 
-// Read charaters from stream IS until a newline is reached.
+// Read characters from stream IS until a newline is reached.
 // Depending on KEEP_NEWLINE, either eat newline from stream or keep
 // it unread.  Characters read are stored and returned as
 // std::string.
@@ -161,7 +161,7 @@ read_until_newline (std::istream& is, bool keep_newline)
         }
       else
         {
-          // No newline charater peeked, so read it, store it, and
+          // No newline character peeked, so read it, store it, and
           // proceed to next.
           char d;
           is.get (d);
@@ -171,4 +171,3 @@ read_until_newline (std::istream& is, bool keep_newline)
 
   return buf.str ();
 }
-
