@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 1996-2017 John W. Eaton
+Copyright (C) 1996-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -25,12 +25,14 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "octave-config.h"
 
+#include <iomanip>
+
 #include "oct-stream.h"
 #include "c-file-ptr-stream.h"
 
 template <typename BUF_T, typename STREAM_T, typename FILE_T>
 class
-octave_tstdiostream : public octave_base_stream
+octave_tstdiostream : public octave::base_stream
 {
 public:
 
@@ -39,10 +41,16 @@ public:
                        octave::mach_info::float_format ff
                          = octave::mach_info::native_float_format (),
                        typename BUF_T::close_fcn cf = BUF_T::file_close)
-    : octave_base_stream (m, ff), nm (n), md (m),
-      s (f ? new STREAM_T (f, cf) : 0), fnum (fid)
+    : octave::base_stream (m, ff), nm (n), md (m),
+      s (f ? new STREAM_T (f, cf) : nullptr), fnum (fid)
   { }
 
+  // No copying!
+
+  octave_tstdiostream (const octave_tstdiostream&) = delete;
+
+  octave_tstdiostream& operator = (const octave_tstdiostream&) = delete;
+
   // Position a stream at OFFSET relative to ORIGIN.
 
   int seek (off_t offset, int origin)
@@ -60,13 +68,13 @@ public:
 
   std::string name (void) const { return nm; }
 
-  std::istream *input_stream (void) { return (md & std::ios::in) ? s : 0; }
+  std::istream * input_stream (void) { return (md & std::ios::in) ? s : nullptr; }
 
-  std::ostream *output_stream (void) { return (md & std::ios::out) ? s : 0; }
+  std::ostream * output_stream (void) { return (md & std::ios::out) ? s : nullptr; }
 
   // FIXME: should not have to cast away const here.
-  BUF_T *rdbuf (void) const
-  { return s ? (const_cast<STREAM_T *> (s))->rdbuf () : 0; }
+  BUF_T * rdbuf (void) const
+  { return s ? (const_cast<STREAM_T *> (s))->rdbuf () : nullptr; }
 
   int file_number (void) const { return fnum; }
 
@@ -88,14 +96,6 @@ protected:
   int fnum;
 
   ~octave_tstdiostream (void) { delete s; }
-
-private:
-
-  // No copying!
-
-  octave_tstdiostream (const octave_tstdiostream&);
-
-  octave_tstdiostream& operator = (const octave_tstdiostream&);
 };
 
 class
@@ -104,7 +104,7 @@ octave_stdiostream
 {
 public:
 
-  octave_stdiostream (const std::string& n, FILE *f = 0,
+  octave_stdiostream (const std::string& n, FILE *f = nullptr,
                       std::ios::openmode m = std::ios::in | std::ios::out,
                       octave::mach_info::float_format ff
                         = octave::mach_info::native_float_format (),
@@ -112,27 +112,25 @@ public:
     : octave_tstdiostream<c_file_ptr_buf, io_c_file_ptr_stream, FILE *>
        (n, f, f ? fileno (f) : -1, m, ff, cf) { }
 
-  static octave_stream
-  create (const std::string& n, FILE *f = 0,
+  static octave::stream
+  create (const std::string& n, FILE *f = nullptr,
           std::ios::openmode m = std::ios::in | std::ios::out,
           octave::mach_info::float_format ff
             = octave::mach_info::native_float_format (),
           c_file_ptr_buf::close_fcn cf = c_file_ptr_buf::file_close)
   {
-    return octave_stream (new octave_stdiostream (n, f, m, ff, cf));
+    return octave::stream (new octave_stdiostream (n, f, m, ff, cf));
   }
 
-protected:
-
-  ~octave_stdiostream (void) { }
-
-private:
-
   // No copying!
 
-  octave_stdiostream (const octave_stdiostream&);
+  octave_stdiostream (const octave_stdiostream&) = delete;
 
-  octave_stdiostream& operator = (const octave_stdiostream&);
+  octave_stdiostream& operator = (const octave_stdiostream&) = delete;
+
+protected:
+
+  ~octave_stdiostream (void) = default;
 };
 
 #if defined (HAVE_ZLIB)
@@ -143,7 +141,7 @@ octave_zstdiostream
 {
 public:
 
-  octave_zstdiostream (const std::string& n, gzFile f = 0, int fid = 0,
+  octave_zstdiostream (const std::string& n, gzFile f = nullptr, int fid = 0,
                        std::ios::openmode m = std::ios::in | std::ios::out,
                        octave::mach_info::float_format ff
                          = octave::mach_info::native_float_format (),
@@ -152,27 +150,25 @@ public:
     : octave_tstdiostream<c_zfile_ptr_buf, io_c_zfile_ptr_stream, gzFile>
        (n, f, fid, m, ff, cf) { }
 
-  static octave_stream
-  create (const std::string& n, gzFile f = 0, int fid = 0,
+  static octave::stream
+  create (const std::string& n, gzFile f = nullptr, int fid = 0,
           std::ios::openmode m = std::ios::in | std::ios::out,
           octave::mach_info::float_format ff
             = octave::mach_info::native_float_format (),
           c_zfile_ptr_buf::close_fcn cf = c_zfile_ptr_buf::file_close)
   {
-    return octave_stream (new octave_zstdiostream (n, f, fid, m, ff, cf));
+    return octave::stream (new octave_zstdiostream (n, f, fid, m, ff, cf));
   }
 
-protected:
-
-  ~octave_zstdiostream (void) { }
-
-private:
-
   // No copying!
 
-  octave_zstdiostream (const octave_zstdiostream&);
+  octave_zstdiostream (const octave_zstdiostream&) = delete;
 
-  octave_zstdiostream& operator = (const octave_zstdiostream&);
+  octave_zstdiostream& operator = (const octave_zstdiostream&) = delete;
+
+protected:
+
+  ~octave_zstdiostream (void) = default;
 };
 
 #endif
