@@ -1,9 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
-   Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,14 +40,11 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
-
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.3.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -72,8 +68,8 @@
 #define yynerrs         octave_tex_nerrs
 
 
-/* First part of user prologue.  */
-#line 23 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:337  */
+/* Copy the first part of user declarations.  */
+#line 23 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:339  */
 
 
 #define YYDEBUG 1
@@ -103,16 +99,13 @@ extern int octave_tex_lex (YYSTYPE *, void *);
 #endif
 
 
-#line 107 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:337  */
+#line 103 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:339  */
+
 # ifndef YY_NULLPTR
-#  if defined __cplusplus
-#   if 201103L <= __cplusplus
-#    define YY_NULLPTR nullptr
-#   else
-#    define YY_NULLPTR 0
-#   endif
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULLPTR nullptr
 #  else
-#   define YY_NULLPTR ((void*)0)
+#   define YY_NULLPTR 0
 #  endif
 # endif
 
@@ -144,10 +137,10 @@ extern int octave_tex_lex (YYSTYPE *, void *);
 extern int octave_tex_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 59 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:352  */
+#line 59 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:355  */
 #include <string>
 
-#line 151 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:352  */
+#line 144 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:355  */
 
 /* Token type.  */
 #ifndef OCTAVE_TEX_TOKENTYPE
@@ -197,7 +190,7 @@ extern int octave_tex_debug;
 
 union OCTAVE_TEX_STYPE
 {
-#line 62 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:352  */
+#line 62 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:355  */
 
   // Leaf symbols produced by the scanner.
   char ch;
@@ -211,7 +204,7 @@ union OCTAVE_TEX_STYPE
   octave::text_element *e_base;
   octave::text_element_list *e_list;
 
-#line 215 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:352  */
+#line 208 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:355  */
 };
 
 typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
@@ -225,7 +218,9 @@ int octave_tex_parse (octave::text_parser_tex& parser);
 
 #endif /* !YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED  */
 
+/* Copy the second part of user declarations.  */
 
+#line 224 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -246,13 +241,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short yytype_uint16;
+typedef unsigned short int yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short yytype_int16;
+typedef short int yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -264,7 +259,7 @@ typedef short yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned
+#  define YYSIZE_T unsigned int
 # endif
 #endif
 
@@ -300,6 +295,15 @@ typedef short yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
+#if !defined _Noreturn \
+     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
+# if defined _MSC_VER && 1200 <= _MSC_VER
+#  define _Noreturn __declspec (noreturn)
+# else
+#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
+# endif
+#endif
+
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -307,7 +311,7 @@ typedef short yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -469,16 +473,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  55
 
+/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
+   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   274
 
-/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex.  */
+   as returned by yylex, without out-of-bounds checking.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -668,22 +672,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                    \
-  do                                                              \
-    if (yychar == YYEMPTY)                                        \
-      {                                                           \
-        yychar = (Token);                                         \
-        yylval = (Value);                                         \
-        YYPOPSTACK (yylen);                                       \
-        yystate = *yyssp;                                         \
-        goto yybackup;                                            \
-      }                                                           \
-    else                                                          \
-      {                                                           \
-        yyerror (parser, YY_("syntax error: cannot back up")); \
-        YYERROR;                                                  \
-      }                                                           \
-  while (0)
+#define YYBACKUP(Token, Value)                                  \
+do                                                              \
+  if (yychar == YYEMPTY)                                        \
+    {                                                           \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
+      goto yybackup;                                            \
+    }                                                           \
+  else                                                          \
+    {                                                           \
+      yyerror (parser, YY_("syntax error: cannot back up")); \
+      YYERROR;                                                  \
+    }                                                           \
+while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -723,38 +727,38 @@ do {                                                                      \
 } while (0)
 
 
-/*-----------------------------------.
-| Print this symbol's value on YYO.  |
-`-----------------------------------*/
+/*----------------------------------------.
+| Print this symbol's value on YYOUTPUT.  |
+`----------------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, octave::text_parser_tex& parser)
+yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, octave::text_parser_tex& parser)
 {
-  FILE *yyoutput = yyo;
-  YYUSE (yyoutput);
+  FILE *yyo = yyoutput;
+  YYUSE (yyo);
   YYUSE (parser);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*---------------------------.
-| Print this symbol on YYO.  |
-`---------------------------*/
+/*--------------------------------.
+| Print this symbol on YYOUTPUT.  |
+`--------------------------------*/
 
 static void
-yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, octave::text_parser_tex& parser)
+yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, octave::text_parser_tex& parser)
 {
-  YYFPRINTF (yyo, "%s %s (",
+  YYFPRINTF (yyoutput, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyo, yytype, yyvaluep, parser);
-  YYFPRINTF (yyo, ")");
+  yy_symbol_value_print (yyoutput, yytype, yyvaluep, parser);
+  YYFPRINTF (yyoutput, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -788,7 +792,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, octave::text_parser_tex& parser)
 {
-  unsigned long yylno = yyrline[yyrule];
+  unsigned long int yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -799,7 +803,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, octave::text_p
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &yyvsp[(yyi + 1) - (yynrhs)]
+                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                               , parser);
       YYFPRINTF (stderr, "\n");
     }
@@ -903,10 +907,7 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            else
-              goto append;
-
-          append:
+            /* Fall through.  */
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -924,7 +925,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
+  return yystpcpy (yyres, yystr) - yyres;
 }
 # endif
 
@@ -1002,10 +1003,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
-                    yysize = yysize1;
-                  else
+                  if (! (yysize <= yysize1
+                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                     return 2;
+                  yysize = yysize1;
                 }
               }
         }
@@ -1017,7 +1018,6 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
-    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1029,10 +1029,9 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
-      yysize = yysize1;
-    else
+    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
       return 2;
+    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1082,96 +1081,97 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, octave::text_parse
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   switch (yytype)
     {
-    case 15: /* CH  */
-#line 92 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+          case 15: /* CH  */
+#line 92 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { }
-#line 1089 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1088 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 16: /* NUM  */
-#line 92 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 92 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { }
-#line 1095 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1094 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 17: /* SYM  */
-#line 92 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 92 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { }
-#line 1101 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1100 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 21: /* simple_string  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).str); }
-#line 1107 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1106 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 22: /* symbol_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1113 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1112 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 23: /* font_modifier_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1119 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1118 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 24: /* fontsize_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1125 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1124 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 25: /* fontname_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1131 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1130 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 26: /* color_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1137 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1136 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 27: /* string_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1143 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1142 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 28: /* superscript_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1149 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1148 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 29: /* subscript_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1155 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1154 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 30: /* combined_script_element  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_base); }
-#line 1161 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1160 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 31: /* string_element_list  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_list); }
-#line 1167 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1166 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
     case 32: /* scoped_string_element_list  */
-#line 93 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
+#line 93 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1257  */
       { delete ((*yyvaluep).e_list); }
-#line 1173 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
+#line 1172 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1257  */
         break;
 
+
       default:
         break;
     }
@@ -1257,31 +1257,23 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
-
 /*------------------------------------------------------------.
-| yynewstate -- push a new state, which is found in yystate.  |
+| yynewstate -- Push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
-yynewstate:
+ yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
-
-/*--------------------------------------------------------------------.
-| yynewstate -- set current state (the top of the stack) to yystate.  |
-`--------------------------------------------------------------------*/
-yysetstate:
-  *yyssp = (yytype_int16) yystate;
+ yysetstate:
+  *yyssp = yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
-#if !defined yyoverflow && !defined YYSTACK_RELOCATE
-    goto yyexhaustedlab;
-#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
+      YYSIZE_T yysize = yyssp - yyss + 1;
 
-# if defined yyoverflow
+#ifdef yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1297,10 +1289,14 @@ yysetstate:
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
+
         yyss = yyss1;
         yyvs = yyvs1;
       }
-# else /* defined YYSTACK_RELOCATE */
+#else /* no yyoverflow */
+# ifndef YYSTACK_RELOCATE
+      goto yyexhaustedlab;
+# else
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1316,22 +1312,22 @@ yysetstate:
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-# undef YYSTACK_RELOCATE
+#  undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
+#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long) yystacksize));
+                  (unsigned long int) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
-#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1340,11 +1336,11 @@ yysetstate:
 
   goto yybackup;
 
-
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
+
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1417,7 +1413,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- do a reduction.  |
+| yyreduce -- Do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1438,180 +1434,180 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 106 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 106 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.str) = new std::string (1, (yyvsp[0].ch)); }
-#line 1444 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1440 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 108 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 108 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyvsp[-1].str)->append (1, (yyvsp[0].ch)); (yyval.str) = (yyvsp[-1].str); }
-#line 1450 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1446 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 112 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 112 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_symbol ((yyvsp[0].sym)); }
-#line 1456 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1452 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 116 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 116 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::bold); }
-#line 1462 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1458 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 118 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 118 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::italic); }
-#line 1468 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1464 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 120 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 120 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::oblique); }
-#line 1474 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1470 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 122 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 122 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::normal); }
-#line 1480 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1476 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 126 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 126 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_fontsize ((yyvsp[-1].num)); }
-#line 1486 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1482 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 130 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 130 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     {
                             (yyval.e_base) = new octave::text_element_fontname (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1495 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1491 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 137 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 137 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     {
                             (yyval.e_base) = new octave::text_element_color (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1504 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1500 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 142 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 142 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     {
                             (yyval.e_base) = new octave::text_element_color ((yyvsp[-3].num), (yyvsp[-2].num), (yyvsp[-1].num));
                           }
-#line 1512 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1508 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 148 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 148 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     {
                             (yyval.e_base) = new octave::text_element_string (*(yyvsp[0].str));
                             delete (yyvsp[0].str);
                           }
-#line 1521 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1517 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 153 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 153 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = (yyvsp[0].e_list); }
-#line 1527 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1523 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 165 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 165 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].ch)); }
-#line 1533 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1529 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 167 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 167 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_list)); }
-#line 1539 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1535 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 169 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 169 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_base)); }
-#line 1545 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1541 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 173 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 173 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].ch)); }
-#line 1551 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1547 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 175 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 175 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_list)); }
-#line 1557 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1553 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 177 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 177 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_base)); }
-#line 1563 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1559 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 181 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 181 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1569 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1565 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 183 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 183 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1575 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1571 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 187 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 187 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_list) = new octave::text_element_list ((yyvsp[0].e_base)); }
-#line 1581 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1577 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 189 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 189 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyvsp[-1].e_list)->push_back ((yyvsp[0].e_base)); (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1587 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1583 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 194 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 194 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1593 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1589 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 196 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 196 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { (yyval.e_list) = new octave::text_element_list (); }
-#line 1599 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1595 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 200 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 200 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { parser.set_parse_result (new octave::text_element_string ("")); }
-#line 1605 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1601 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 202 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1652  */
+#line 202 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1646  */
     { parser.set_parse_result ((yyvsp[0].e_list)); }
-#line 1611 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1607 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
     break;
 
 
-#line 1615 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1652  */
+#line 1611 "libinterp/corefcn/oct-tex-parser.cc" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1636,13 +1632,14 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-  {
-    const int yylhs = yyr1[yyn] - YYNTOKENS;
-    const int yyi = yypgoto[yylhs] + *yyssp;
-    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
-               ? yytable[yyi]
-               : yydefgoto[yylhs]);
-  }
+
+  yyn = yyr1[yyn];
+
+  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
+  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
+    yystate = yytable[yystate];
+  else
+    yystate = yydefgoto[yyn - YYNTOKENS];
 
   goto yynewstate;
 
@@ -1725,10 +1722,12 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-  /* Pacify compilers when the user code never invokes YYERROR and the
-     label yyerrorlab therefore never appears in user code.  */
-  if (0)
-    YYERROR;
+
+  /* Pacify compilers like GCC when the user code never invokes
+     YYERROR and the label yyerrorlab therefore never appears in user
+     code.  */
+  if (/*CONSTCOND*/ 0)
+     goto yyerrorlab;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1790,7 +1789,6 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
-
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1798,7 +1796,6 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1809,10 +1806,6 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
-
-/*-----------------------------------------------------.
-| yyreturn -- parsing is finished, return the result.  |
-`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1842,7 +1835,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 205 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1918  */
+#line 205 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1906  */
 
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
