@@ -1,9 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
-   Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,9 +30,6 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
-
 #ifndef YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED
 # define YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED
 /* Debug traces.  */
@@ -52,10 +48,10 @@
 extern int octave_tex_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 59 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1921  */
+#line 59 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1909  */
 #include <string>
 
-#line 59 "libinterp/corefcn/oct-tex-parser.h" /* yacc.c:1921  */
+#line 55 "libinterp/corefcn/oct-tex-parser.h" /* yacc.c:1909  */
 
 /* Token type.  */
 #ifndef OCTAVE_TEX_TOKENTYPE
@@ -105,7 +101,7 @@ extern int octave_tex_debug;
 
 union OCTAVE_TEX_STYPE
 {
-#line 62 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1921  */
+#line 62 "libinterp/corefcn/oct-tex-parser.yy" /* yacc.c:1909  */
 
   // Leaf symbols produced by the scanner.
   char ch;
@@ -119,7 +115,7 @@ union OCTAVE_TEX_STYPE
   octave::text_element *e_base;
   octave::text_element_list *e_list;
 
-#line 123 "libinterp/corefcn/oct-tex-parser.h" /* yacc.c:1921  */
+#line 119 "libinterp/corefcn/oct-tex-parser.h" /* yacc.c:1909  */
 };
 
 typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
