@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 1996-2017 John W. Eaton
+Copyright (C) 1996-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -39,7 +39,7 @@ DEFUN (pinv, args, ,
        doc: /* -*- texinfo -*-
 @deftypefn  {} {} pinv (@var{x})
 @deftypefnx {} {} pinv (@var{x}, @var{tol})
-Return the Moore-Penrose pseudoinverse of @var{x}.
+Return the @nospell{Moore-Penrose} pseudoinverse of @var{x}.
 
 Singular values less than @var{tol} are ignored.
 
@@ -59,7 +59,7 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
 
   octave_value arg = args(0);
 
-  if (arg.is_empty ())
+  if (arg.isempty ())
     return ovl (Matrix ());
 
   octave_value retval;
@@ -77,7 +77,7 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
           if (tol < 0.0)
             error ("pinv: TOL must be greater than zero");
 
-          if (arg.is_real_type ())
+          if (arg.isreal ())
             retval = arg.float_diag_matrix_value ().pseudo_inverse (tol);
           else
             retval = arg.float_complex_diag_matrix_value ().pseudo_inverse (tol);
@@ -91,7 +91,7 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
           if (tol < 0.0)
             error ("pinv: TOL must be greater than zero");
 
-          if (arg.is_real_type ())
+          if (arg.isreal ())
             retval = arg.diag_matrix_value ().pseudo_inverse (tol);
           else
             retval = arg.complex_diag_matrix_value ().pseudo_inverse (tol);
@@ -110,13 +110,13 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
       if (tol < 0.0)
         error ("pinv: TOL must be greater than zero");
 
-      if (arg.is_real_type ())
+      if (arg.isreal ())
         {
           FloatMatrix m = arg.float_matrix_value ();
 
           retval = m.pseudo_inverse (tol);
         }
-      else if (arg.is_complex_type ())
+      else if (arg.iscomplex ())
         {
           FloatComplexMatrix m = arg.float_complex_matrix_value ();
 
@@ -134,13 +134,13 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
       if (tol < 0.0)
         error ("pinv: TOL must be greater than zero");
 
-      if (arg.is_real_type ())
+      if (arg.isreal ())
         {
           Matrix m = arg.matrix_value ();
 
           retval = m.pseudo_inverse (tol);
         }
-      else if (arg.is_complex_type ())
+      else if (arg.iscomplex ())
         {
           ComplexMatrix m = arg.complex_matrix_value ();
 
@@ -155,6 +155,9 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
 
 /*
 %!shared a, b, tol, hitol, d, u, x, y
+%! old_state = rand ("state");
+%! restore_state = onCleanup (@() rand ("state", old_state));
+%! rand ("state", 42); # initialize generator to make behavior reproducible
 %! a = reshape (rand*[1:16], 4, 4);  # Rank 2 matrix
 %! b = pinv (a);
 %! tol = 4e-14;
@@ -163,7 +166,8 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
 %! u = rand (4);                     # Could be singular by freak accident
 %! x = inv (u)*d*u;
 %! y = pinv (x, sqrt (eps));
-%!
+
+## Verify Penrose conditions for pseudoinverse
 %!assert (a*b*a, a, tol)
 %!assert (b*a*b, b, tol)
 %!assert ((b*a)', b*a, tol)
@@ -188,4 +192,13 @@ tol = max ([rows(@var{x}), columns(@var{x})]) * norm (@var{x}) * eps
 %! y = pinv (x, 2);
 %! assert (diag (y), [1/3 1/2 0 0 0]');
 
+## Test special case of 0 scalars and vectors
+%!assert (pinv (0), 0)
+%!assert (pinv ([0, 0, 0]), [0; 0; 0])
+%!assert (pinv (single (0)), single (0))
+%!assert (pinv (single ([0, 0, 0])), single ([0; 0; 0]))
+%!assert (pinv (complex (0,0)), 0)
+%!assert (pinv (complex ([0,0,0], [0,0,0])), [0; 0; 0])
+%!assert (pinv (complex (single (0),0)), single (0))
+%!assert (pinv (complex (single ([0,0,0]), [0,0,0])), single ([0; 0; 0]))
 */
