@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1993-2018 John W. Eaton
+Copyright (C) 1993-2019 John W. Eaton
 Copyright (C) 2009 VZLU Prague, a.s.
 
 This file is part of Octave.
@@ -97,7 +97,7 @@ namespace octave
     bool retval = false;
 
     octave_value ov_fcn
-      = octave::load_fcn_from_file (ff, dir_name, dispatch_type,
+      = load_fcn_from_file (ff, dir_name, dispatch_type,
                                     package_name);
 
     if (ov_fcn.is_defined ())
@@ -167,7 +167,8 @@ namespace octave
 
                             if (! dispatch_type.empty ())
                               {
-                                load_path& lp = __get_load_path__ ("out_of_date_check");
+                                load_path& lp
+                                  = __get_load_path__ ("out_of_date_check");
 
                                 file = lp.find_method (dispatch_type, nm,
                                                        dir_name, pack);
@@ -210,7 +211,8 @@ namespace octave
 
                             if (file.empty ())
                               {
-                                load_path& lp = __get_load_path__ ("out_of_date_check");
+                                load_path& lp
+                                  = __get_load_path__ ("out_of_date_check");
                                 file = lp.find_fcn (nm, dir_name, pack);
                               }
                           }
@@ -283,8 +285,8 @@ namespace octave
                     // breakpoints associated with it
                     if (clear_breakpoints)
                       {
-                        octave::bp_table& bptab
-                          = octave::__get_bp_table__ ("out_of_date_check");
+                        bp_table& bptab
+                          = __get_bp_table__ ("out_of_date_check");
 
                         bptab.remove_all_breakpoints_in_file (canonical_nm,
                                                               true);
@@ -354,15 +356,6 @@ namespace octave
     return (q != inferior_classes.end ());
   }
 
-  octave_value
-  symbol_table::find (const std::string& name, const octave_value_list& args,
-                      bool skip_variables, bool local_funcs)
-  {
-    return (m_current_scope
-            ? m_current_scope.find (name, args, skip_variables, local_funcs)
-            : octave_value ());
-  }
-
   octave_value
   symbol_table::builtin_find (const std::string& name)
   {
@@ -387,17 +380,17 @@ namespace octave
 
   octave_value
   symbol_table::fcn_table_find (const std::string& name,
-                                const octave_value_list& args, bool local_funcs)
+                                const octave_value_list& args)
   {
     fcn_table_iterator p = m_fcn_table.find (name);
 
     if (p != m_fcn_table.end ())
-      return p->second.find (args, local_funcs);
+      return p->second.find (args);
     else
       {
         fcn_info finfo (name);
 
-        octave_value fcn = finfo.find (args, local_funcs);
+        octave_value fcn = finfo.find (args);
 
         if (fcn.is_defined ())
           m_fcn_table[name] = finfo;
@@ -408,95 +401,66 @@ namespace octave
     return octave_value ();
   }
 
-  octave_value
-  symbol_table::find_function (const std::string& name,
-                               const octave_value_list& args, bool local_funcs)
+  octave_value symbol_table::find_function (const std::string& name)
   {
-    octave_value retval;
+    if (name.empty ())
+      return octave_value ();
 
-    if (! name.empty () && name[0] == '@')
+    if (name[0] == '@')
       {
-        // Look for a class specific function.
-        std::string dispatch_type =
-          name.substr (1, name.find_first_of (sys::file_ops::dir_sep_str ()) - 1);
-
-        std::string method;
-        size_t pos = name.find_last_of (sys::file_ops::dir_sep_str ());
-        if (pos != std::string::npos)
-          method = name.substr (pos + 1);
-
-        retval = find_method (method, dispatch_type);
-      }
-    else
-      {
-        size_t pos = name.find_first_of ('>');
+        size_t pos = name.find_first_of ('/');
 
         if (pos == std::string::npos)
-          retval = find (name, args, true, local_funcs);
-        else
-          {
-            std::string fcn_scope = name.substr (0, pos);
-            symbol_scope stored_scope = m_current_scope;
-            m_current_scope = m_top_scope;
-            octave_value parent = find_function (name.substr (0, pos),
-                                                 octave_value_list (), false);
+          return octave_value ();
 
-            if (parent.is_defined ())
-              {
-                octave_function *parent_fcn = parent.function_value ();
+        std::string method = name.substr (pos+1);
+        std::string dispatch_type = name.substr (1, pos-1);
 
-                if (parent_fcn)
-                  {
-                    m_current_scope = parent_fcn->scope ();
-
-                    if (m_current_scope && m_current_scope != m_top_scope)
-                      retval = find_function (name.substr (pos + 1), args);
-                  }
-              }
-
-            m_current_scope = stored_scope;
-          }
+        return find_method (method, dispatch_type);
       }
-
-    return retval;
+    else
+      return find_function (name, ovl ());
   }
 
-  // look for @class/method>subfunction
   octave_value
-  symbol_table::find_submethod (const std::string& name,
-                                const std::string& dispatch_type)
+  symbol_table::find_function (const std::string& name,
+                               const octave_value_list& args)
   {
     octave_value fcn;
 
-    std::string full_name = '@' + dispatch_type +
-      sys::file_ops::dir_sep_str () + name;
-    size_t pos = full_name.find_first_of ('>');
-
-    if (pos != std::string::npos)
+    if (m_current_scope)
       {
-        std::string fcn_scope = full_name.substr (0, pos);
-        symbol_scope stored_scope = m_current_scope;
-        m_current_scope = m_top_scope;
-        octave_value parent = find_function (full_name.substr (0, pos),
-                                             octave_value_list (), false);
-        if (parent.is_defined ())
-          {
-            octave_function *parent_fcn = parent.function_value ();
+        fcn = m_current_scope.find_subfunction (name);
 
-            if (parent_fcn)
-              {
-                m_current_scope = parent_fcn->scope ();
-
-                if (m_current_scope && m_current_scope != m_top_scope)
-                  fcn = find_function (full_name.substr (pos + 1),
-                                       octave_value_list ());
-              }
-          }
-
-        m_current_scope = stored_scope;
+        if (fcn.is_defined ())
+          return fcn;
       }
 
-    return fcn;
+    return fcn_table_find (name, args);
+  }
+
+  // FIXME: this function only finds legacy class methods, not
+  // classdef methods.
+
+  octave_value
+  symbol_table::find_method (const std::string& name,
+                             const std::string& dispatch_type)
+  {
+    fcn_table_const_iterator p = m_fcn_table.find (name);
+
+    if (p != m_fcn_table.end ())
+      return p->second.find_method (dispatch_type);
+    else
+      {
+        fcn_info finfo (name);
+
+        octave_value fcn = finfo.find_method (dispatch_type);
+
+        if (fcn.is_defined ())
+          m_fcn_table[name] = finfo;
+
+        return fcn;
+      }
   }
 
   template <template <typename, typename...> class C, typename V,
