@@ -260,6 +260,9 @@ namespace octave
   {
 #if defined (OCTAVE_USE_WINDOWS_API)
 
+    // FIXME: When Octave switches to C++17, consider replacing this function
+    //        by https://en.cppreference.com/w/cpp/filesystem/equivalent.
+
     bool retval = false;
 
     std::wstring file1w = octave::sys::u8_to_wstring (file1);
@@ -295,7 +298,13 @@ namespace octave
               {
                 retval = (hfi1.dwVolumeSerialNumber == hfi2.dwVolumeSerialNumber
                           && hfi1.nFileIndexHigh == hfi2.nFileIndexHigh
-                          && hfi1.nFileIndexLow == hfi2.nFileIndexLow);
+                          && hfi1.nFileIndexLow == hfi2.nFileIndexLow
+                          && hfi1.nFileSizeHigh == hfi2.nFileSizeHigh
+                          && hfi1.nFileSizeLow == hfi2.nFileSizeLow
+                          && hfi1.ftLastWriteTime.dwLowDateTime
+                             == hfi2.ftLastWriteTime.dwLowDateTime
+                          && hfi1.ftLastWriteTime.dwHighDateTime
+                             == hfi2.ftLastWriteTime.dwHighDateTime);
               }
 
             CloseHandle (hfile2);
@@ -544,12 +553,16 @@ namespace octave
   {
 #if defined (HAVE__KBHIT) && defined (HAVE__GETCH)
     // This essentially means we are on a Windows system.
+
+    // The value to return when wait is false and no input is ready.
+    static constexpr int eof = std::istream::traits_type::eof ();
+
     int c;
 
     if (wait)
       c = _getch ();
     else
-      c = (! _kbhit ()) ? 0 : _getch ();
+      c = (! _kbhit ()) ? eof : _getch ();
 
 #else
     raw_mode (true, wait);
@@ -566,7 +579,10 @@ namespace octave
     int c = std::cin.get ();
 
     if (std::cin.fail () || std::cin.eof ())
-      std::cin.clear ();
+      {
+        std::cin.clear ();
+        clearerr (stdin);
+      }
 
     // Restore it, enabling system call restarts (if possible).
     octave::set_interrupt_handler (saved_interrupt_handler, true);
@@ -761,7 +777,7 @@ get_regkey_value (HKEY h_rootkey, const std::string subkey,
     return result;
 
   if (type == REG_DWORD)
-    value = octave_int32 (*data);
+    value = octave_int32 (*(reinterpret_cast<DWORD *>(data)));
   else if (type == REG_SZ || type == REG_EXPAND_SZ)
     value = string_vector (octave::sys::u8_from_wstring (
                                         reinterpret_cast<wchar_t *> (data)));
