@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1995-2018 John W. Eaton
+Copyright (C) 1995-2019 John W. Eaton
 
 This file is part of Octave.
 
@@ -26,8 +26,8 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <cerrno>
 #include <cstdlib>
-#include <new>
 
+#include <new>
 #include <sstream>
 #include <string>
 
@@ -83,8 +83,8 @@ under the terms of the GNU General Public License as published by\n\
 the Free Software Foundation, either version 3 of the License, or\n\
 (at your option) any later version.\n\
 \n\
-GNU Octave is distributed in the hope that it will be useful,\n\
-but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
+GNU Octave is distributed in the hope that it will be useful, but\n\
+WITHOUT ANY WARRANTY; without even the implied warranty of\n\
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
 GNU General Public License for more details.\n\
 \n\
@@ -347,12 +347,6 @@ specified option.
 @seealso{computer}
 @end deftypefn */)
 {
-#if defined (ENABLE_DYNAMIC_LINKING)
-  bool octave_supports_dynamic_linking = true;
-#else
-  bool octave_supports_dynamic_linking = false;
-#endif
-
   static octave_scalar_map config;
   static octave_scalar_map build_env;
   static octave_scalar_map build_features;
@@ -382,12 +376,6 @@ specified option.
            { "ENABLE_DOCS", false },
 #endif
 
-#if defined (ENABLE_DYNAMIC_LINKING)
-           { "ENABLE_DYNAMIC_LINKING", true },
-#else
-           { "ENABLE_DYNAMIC_LINKING", false },
-#endif
-
 #if defined (OCTAVE_ENABLE_FLOAT_TRUNCATE)
            { "ENABLE_FLOAT_TRUNCATE", true },
 #else
@@ -489,7 +477,6 @@ specified option.
            { "DEFS", octave::build_env::DEFS },
            { "DL_LD", octave::build_env::DL_LD },
            { "DL_LDFLAGS", octave::build_env::DL_LDFLAGS },
-           { "DL_LIBS", octave::build_env::DL_LIBS },
            { "GCC_VERSION", octave::build_env::GCC_VERSION },
            { "GXX_VERSION", octave::build_env::GXX_VERSION },
            { "EXEEXT", octave::build_env::EXEEXT },
@@ -542,9 +529,6 @@ specified option.
            { "OCT_LINK_DEPS", octave::build_env::OCT_LINK_DEPS },
            { "OCT_LINK_OPTS", octave::build_env::OCT_LINK_OPTS },
            { "OPENGL_LIBS", octave::build_env::OPENGL_LIBS },
-           { "OSMESA_CPPFLAGS", octave::build_env::OSMESA_CPPFLAGS },
-           { "OSMESA_LDFLAGS", octave::build_env::OSMESA_LDFLAGS },
-           { "OSMESA_LIBS", octave::build_env::OSMESA_LIBS },
            { "PCRE_CPPFLAGS", octave::build_env::PCRE_CPPFLAGS },
            { "PCRE_LDFLAGS", octave::build_env::PCRE_LDFLAGS },
            { "PCRE_LIBS", octave::build_env::PCRE_LIBS },
@@ -559,10 +543,10 @@ specified option.
            { "QT_CPPFLAGS", octave::build_env::QT_CPPFLAGS },
            { "QT_LDFLAGS", octave::build_env::QT_LDFLAGS },
            { "QT_LIBS", octave::build_env::QT_LIBS },
+           { "QT_OPENGL_LIBS", octave::build_env::QT_OPENGL_LIBS },
            { "RANLIB", octave::build_env::RANLIB },
            { "RDYNAMIC_FLAG", octave::build_env::RDYNAMIC_FLAG },
            { "READLINE_LIBS", octave::build_env::READLINE_LIBS },
-           { "SED", octave::build_env::SED },
            { "SHARED_LIBS", octave::build_env::SHARED_LIBS },
            { "SH_LD", octave::build_env::SH_LD },
            { "SH_LDFLAGS", octave::build_env::SH_LDFLAGS },
@@ -608,8 +592,6 @@ specified option.
       config.assign ("mac", octave_value (mac_system));
       config.assign ("windows", octave_value (windows_system));
 
-      config.assign ("dld", octave_value (octave_supports_dynamic_linking));
-
       octave::mach_info::float_format ff = octave::mach_info::native_float_format ();
       config.assign ("float_format",
                      octave_value (octave::mach_info::float_format_as_string (ff)));
