@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2006-2018 Alexander Barth
+Copyright (C) 2006-2019 Alexander Barth
 Copyright (C) 2009 David Bateman
 
 This file is part of Octave.
@@ -31,11 +31,11 @@ along with Octave; see the file COPYING.  If not, see
 #include <string>
 #include <fstream>
 #include <iomanip>
-#include <iostream>
 
 #include "dir-ops.h"
 #include "file-ops.h"
 #include "file-stat.h"
+#include "lo-sysdep.h"
 #include "oct-env.h"
 #include "oct-handle.h"
 #include "glob-match.h"
@@ -637,8 +637,11 @@ Undocumented internal function
         }
       else
         {
+          std::string ascii_fname = octave::sys::get_ASCII_filename (file);
+
           // FIXME: Does ascii mode need to be flagged here?
-          std::ifstream ifile (file.c_str (), std::ios::in | std::ios::binary);
+          std::ifstream ifile (ascii_fname.c_str (),
+                               std::ios::in | std::ios::binary);
 
           if (! ifile.is_open ())
             error ("__ftp_mput__: unable to open file");
