@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2008-2018 David Bateman
+Copyright (C) 2008-2019 David Bateman
 
 This file is part of Octave.
 
@@ -41,9 +41,10 @@ along with Octave; see the file COPYING.  If not, see
 #include "oct-map.h"
 #include "ov.h"
 #include "ovl.h"
+#include "parse.h"
 
-DEFUN_DLD (amd, args, nargout,
-           doc: /* -*- texinfo -*-
+DEFMETHOD_DLD (amd, interp, args, nargout,
+               doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{p} =} amd (@var{S})
 @deftypefnx {} {@var{p} =} amd (@var{S}, @var{opts})
 
@@ -143,6 +144,9 @@ The author of the code itself is Timothy A. Davis
   Matrix xinfo (AMD_INFO, 1);
   double *Info = xinfo.fortran_vec ();
 
+  // Lock the function to not loose the SuiteSparse_config structure
+  interp.mlock ();
+
   // FIXME: how can we manage the memory allocation of amd
   //        in a cleaner manner?
   SUITESPARSE_ASSIGN_FPTR (malloc_func, amd_malloc, malloc);
@@ -182,7 +186,7 @@ The author of the code itself is Timothy A. Davis
 %!shared A, A2, opts
 %! A = ones (20, 30);
 %! A2 = ones (30, 30);
-%!
+
 %!testif HAVE_AMD
 %! assert(amd (A2), [1:30]);
 %! opts.dense = 25;
@@ -190,7 +194,9 @@ The author of the code itself is Timothy A. Davis
 %! opts.aggressive = 1;
 %! assert(amd (A2, opts), [1:30]);
 
+%!testif HAVE_AMD
+%! assert (amd ([]), zeros (1,0))
+
 %!error <S must be a square matrix|was unavailable or disabled> amd (A)
 %!error amd (A2, 2)
-%!error <matrix S is corrupted|was unavailable or disabled> amd ([])
 */
