@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 2008-2017 Jaroslav Hajek
+Copyright (C) 2008-2019 Jaroslav Hajek
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -91,26 +91,27 @@ CONVDECL (float_complex_diag_matrix_to_complex_diag_matrix)
 }
 
 void
-install_fcdm_fcdm_ops (void)
+install_fcdm_fcdm_ops (octave::type_info& ti)
 {
-  INSTALL_UNOP (op_uplus, octave_float_complex_diag_matrix, uplus);
-  INSTALL_UNOP (op_uminus, octave_float_complex_diag_matrix, uminus);
-  INSTALL_UNOP (op_transpose, octave_float_complex_diag_matrix, transpose);
-  INSTALL_UNOP (op_hermitian, octave_float_complex_diag_matrix, hermitian);
+  INSTALL_UNOP_TI (ti, op_uplus, octave_float_complex_diag_matrix, uplus);
+  INSTALL_UNOP_TI (ti, op_uminus, octave_float_complex_diag_matrix, uminus);
+  INSTALL_UNOP_TI (ti, op_transpose, octave_float_complex_diag_matrix, transpose);
+  INSTALL_UNOP_TI (ti, op_hermitian, octave_float_complex_diag_matrix, hermitian);
 
-  INSTALL_BINOP (op_add, octave_float_complex_diag_matrix,
-                 octave_float_complex_diag_matrix, add);
-  INSTALL_BINOP (op_sub, octave_float_complex_diag_matrix,
-                 octave_float_complex_diag_matrix, sub);
-  INSTALL_BINOP (op_mul, octave_float_complex_diag_matrix,
-                 octave_float_complex_diag_matrix, mul);
-  INSTALL_BINOP (op_div, octave_float_complex_diag_matrix,
-                 octave_float_complex_diag_matrix, div);
-  INSTALL_BINOP (op_ldiv, octave_float_complex_diag_matrix,
-                 octave_float_complex_diag_matrix, ldiv);
+  INSTALL_BINOP_TI (ti, op_add, octave_float_complex_diag_matrix,
+                    octave_float_complex_diag_matrix, add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_float_complex_diag_matrix,
+                    octave_float_complex_diag_matrix, sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_float_complex_diag_matrix,
+                    octave_float_complex_diag_matrix, mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_float_complex_diag_matrix,
+                    octave_float_complex_diag_matrix, div);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_float_complex_diag_matrix,
+                    octave_float_complex_diag_matrix, ldiv);
 
-  INSTALL_ASSIGNCONV (octave_float_complex_diag_matrix,
-                      octave_float_complex_matrix, octave_float_complex_matrix);
-  INSTALL_WIDENOP (octave_float_complex_diag_matrix, octave_complex_diag_matrix,
-                   float_complex_diag_matrix_to_complex_diag_matrix);
+  INSTALL_ASSIGNCONV_TI (ti, octave_float_complex_diag_matrix,
+                         octave_float_complex_matrix, octave_float_complex_matrix);
+  INSTALL_WIDENOP_TI (ti, octave_float_complex_diag_matrix,
+                      octave_complex_diag_matrix,
+                      float_complex_diag_matrix_to_complex_diag_matrix);
 }
