@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 1996-2017 John W. Eaton
+Copyright (C) 1996-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -149,44 +149,55 @@ DEFNDASSIGNOP_FN (dbl_assign, complex_matrix, float_matrix,
                   complex_array, assign)
 
 void
-install_fcm_fm_ops (void)
+install_fcm_fm_ops (octave::type_info& ti)
 {
-  INSTALL_BINOP (op_add, octave_float_complex_matrix, octave_float_matrix, add);
-  INSTALL_BINOP (op_sub, octave_float_complex_matrix, octave_float_matrix, sub);
-  INSTALL_BINOP (op_mul, octave_float_complex_matrix, octave_float_matrix, mul);
-  INSTALL_BINOP (op_div, octave_float_complex_matrix, octave_float_matrix, div);
-  INSTALL_BINOP (op_pow, octave_float_complex_matrix, octave_float_matrix, pow);
-  INSTALL_BINOP (op_ldiv, octave_float_complex_matrix,
-                 octave_float_matrix, ldiv);
-  INSTALL_BINOP (op_lt, octave_float_complex_matrix, octave_float_matrix, lt);
-  INSTALL_BINOP (op_le, octave_float_complex_matrix, octave_float_matrix, le);
-  INSTALL_BINOP (op_eq, octave_float_complex_matrix, octave_float_matrix, eq);
-  INSTALL_BINOP (op_ge, octave_float_complex_matrix, octave_float_matrix, ge);
-  INSTALL_BINOP (op_gt, octave_float_complex_matrix, octave_float_matrix, gt);
-  INSTALL_BINOP (op_ne, octave_float_complex_matrix, octave_float_matrix, ne);
-  INSTALL_BINOP (op_el_mul, octave_float_complex_matrix,
-                 octave_float_matrix, el_mul);
-  INSTALL_BINOP (op_el_div, octave_float_complex_matrix,
-                 octave_float_matrix, el_div);
-  INSTALL_BINOP (op_el_pow, octave_float_complex_matrix,
-                 octave_float_matrix, el_pow);
-  INSTALL_BINOP (op_el_ldiv, octave_float_complex_matrix,
-                 octave_float_matrix, el_ldiv);
-  INSTALL_BINOP (op_el_and, octave_float_complex_matrix,
-                 octave_float_matrix, el_and);
-  INSTALL_BINOP (op_el_or, octave_float_complex_matrix,
-                 octave_float_matrix, el_or);
-  INSTALL_BINOP (op_mul_trans, octave_float_complex_matrix,
-                 octave_float_matrix, mul_trans);
-  INSTALL_BINOP (op_mul_herm, octave_float_complex_matrix,
-                 octave_float_matrix, mul_trans);
+  INSTALL_BINOP_TI (ti, op_add, octave_float_complex_matrix, octave_float_matrix,
+                    add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_float_complex_matrix, octave_float_matrix,
+                    sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_float_complex_matrix, octave_float_matrix,
+                    mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_float_complex_matrix, octave_float_matrix,
+                    div);
+  INSTALL_BINOP_TI (ti, op_pow, octave_float_complex_matrix, octave_float_matrix,
+                    pow);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_float_complex_matrix,
+                    octave_float_matrix, ldiv);
+  INSTALL_BINOP_TI (ti, op_lt, octave_float_complex_matrix, octave_float_matrix,
+                    lt);
+  INSTALL_BINOP_TI (ti, op_le, octave_float_complex_matrix, octave_float_matrix,
+                    le);
+  INSTALL_BINOP_TI (ti, op_eq, octave_float_complex_matrix, octave_float_matrix,
+                    eq);
+  INSTALL_BINOP_TI (ti, op_ge, octave_float_complex_matrix, octave_float_matrix,
+                    ge);
+  INSTALL_BINOP_TI (ti, op_gt, octave_float_complex_matrix, octave_float_matrix,
+                    gt);
+  INSTALL_BINOP_TI (ti, op_ne, octave_float_complex_matrix, octave_float_matrix,
+                    ne);
+  INSTALL_BINOP_TI (ti, op_el_mul, octave_float_complex_matrix,
+                    octave_float_matrix, el_mul);
+  INSTALL_BINOP_TI (ti, op_el_div, octave_float_complex_matrix,
+                    octave_float_matrix, el_div);
+  INSTALL_BINOP_TI (ti, op_el_pow, octave_float_complex_matrix,
+                    octave_float_matrix, el_pow);
+  INSTALL_BINOP_TI (ti, op_el_ldiv, octave_float_complex_matrix,
+                    octave_float_matrix, el_ldiv);
+  INSTALL_BINOP_TI (ti, op_el_and, octave_float_complex_matrix,
+                    octave_float_matrix, el_and);
+  INSTALL_BINOP_TI (ti, op_el_or, octave_float_complex_matrix,
+                    octave_float_matrix, el_or);
+  INSTALL_BINOP_TI (ti, op_mul_trans, octave_float_complex_matrix,
+                    octave_float_matrix, mul_trans);
+  INSTALL_BINOP_TI (ti, op_mul_herm, octave_float_complex_matrix,
+                    octave_float_matrix, mul_trans);
 
-  INSTALL_CATOP (octave_float_complex_matrix, octave_float_matrix, fcm_fm);
-  INSTALL_CATOP (octave_complex_matrix, octave_float_matrix, cm_fm);
-  INSTALL_CATOP (octave_float_complex_matrix, octave_matrix, fcm_m);
+  INSTALL_CATOP_TI (ti, octave_float_complex_matrix, octave_float_matrix, fcm_fm);
+  INSTALL_CATOP_TI (ti, octave_complex_matrix, octave_float_matrix, cm_fm);
+  INSTALL_CATOP_TI (ti, octave_float_complex_matrix, octave_matrix, fcm_m);
 
-  INSTALL_ASSIGNOP (op_asn_eq, octave_float_complex_matrix,
-                    octave_float_matrix, assign);
-  INSTALL_ASSIGNOP (op_asn_eq, octave_complex_matrix,
-                    octave_float_matrix, dbl_assign);
+  INSTALL_ASSIGNOP_TI (ti, op_asn_eq, octave_float_complex_matrix,
+                       octave_float_matrix, assign);
+  INSTALL_ASSIGNOP_TI (ti, op_asn_eq, octave_complex_matrix,
+                       octave_float_matrix, dbl_assign);
 }
