@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 2004-2016 John W. Eaton
+Copyright (C) 2004-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -47,7 +47,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "op-int.h"
 #include "ops.h"
 
-// Concatentation of mixed integer types:
+// Concatenation of mixed integer types:
 
 OCTAVE_CONCAT_FN2 (int8, int16)
 OCTAVE_CONCAT_FN2 (int8, int32)
@@ -182,7 +182,7 @@ OCTAVE_CHAR_INT_CONCAT_FN (uint32)
 OCTAVE_CHAR_INT_CONCAT_FN (uint64)
 
 void
-install_int_concat_ops (void)
+install_int_concat_ops (octave::type_info& ti)
 {
   OCTAVE_INSTALL_CONCAT_FN2 (int8, int16);
   OCTAVE_INSTALL_CONCAT_FN2 (int8, int32);
@@ -316,4 +316,3 @@ install_int_concat_ops (void)
   OCTAVE_INSTALL_CHAR_INT_CONCAT_FN (uint32);
   OCTAVE_INSTALL_CHAR_INT_CONCAT_FN (uint64);
 }
-
