@@ -1,23 +1,23 @@
 /*
 
-Copyright (C) 2004-2016 David Bateman
+Copyright (C) 2004-2019 David Bateman
 Copyright (C) 1998-2004 Andy Adler
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -135,48 +135,54 @@ DEFCATOP_FN (scm_sm, sparse_complex_matrix, sparse_matrix, concat)
 DEFASSIGNOP_FN (assign, sparse_complex_matrix, sparse_matrix, assign)
 
 void
-install_scm_sm_ops (void)
+install_scm_sm_ops (octave::type_info& ti)
 {
-  INSTALL_BINOP (op_add, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 add);
-  INSTALL_BINOP (op_sub, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 sub);
-  INSTALL_BINOP (op_mul, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 mul);
-  INSTALL_BINOP (op_div, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 div);
-  INSTALL_BINOP (op_pow, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 pow);
-  INSTALL_BINOP (op_ldiv, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 ldiv);
-  INSTALL_BINOP (op_lt, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 lt);
-  INSTALL_BINOP (op_le, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 le);
-  INSTALL_BINOP (op_eq, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 eq);
-  INSTALL_BINOP (op_ge, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 ge);
-  INSTALL_BINOP (op_gt, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 gt);
-  INSTALL_BINOP (op_ne, octave_sparse_complex_matrix, octave_sparse_matrix,
-                 ne);
-  INSTALL_BINOP (op_el_mul, octave_sparse_complex_matrix,
-                 octave_sparse_matrix, el_mul);
-  INSTALL_BINOP (op_el_div, octave_sparse_complex_matrix,
-                 octave_sparse_matrix, el_div);
-  INSTALL_BINOP (op_el_pow, octave_sparse_complex_matrix,
-                 octave_sparse_matrix, el_pow);
-  INSTALL_BINOP (op_el_ldiv, octave_sparse_complex_matrix,
-                 octave_sparse_matrix, el_ldiv);
-  INSTALL_BINOP (op_el_and, octave_sparse_complex_matrix,
-                 octave_sparse_matrix, el_and);
-  INSTALL_BINOP (op_el_or, octave_sparse_complex_matrix,
-                 octave_sparse_matrix, el_or);
+  INSTALL_BINOP_TI (ti, op_add, octave_sparse_complex_matrix,
+                    octave_sparse_matrix,
+                    add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_sparse_complex_matrix,
+                    octave_sparse_matrix,
+                    sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_sparse_complex_matrix,
+                    octave_sparse_matrix,
+                    mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_sparse_complex_matrix,
+                    octave_sparse_matrix,
+                    div);
+  INSTALL_BINOP_TI (ti, op_pow, octave_sparse_complex_matrix,
+                    octave_sparse_matrix,
+                    pow);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_sparse_complex_matrix,
+                    octave_sparse_matrix,
+                    ldiv);
+  INSTALL_BINOP_TI (ti, op_lt, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    lt);
+  INSTALL_BINOP_TI (ti, op_le, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    le);
+  INSTALL_BINOP_TI (ti, op_eq, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    eq);
+  INSTALL_BINOP_TI (ti, op_ge, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    ge);
+  INSTALL_BINOP_TI (ti, op_gt, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    gt);
+  INSTALL_BINOP_TI (ti, op_ne, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    ne);
+  INSTALL_BINOP_TI (ti, op_el_mul, octave_sparse_complex_matrix,
+                    octave_sparse_matrix, el_mul);
+  INSTALL_BINOP_TI (ti, op_el_div, octave_sparse_complex_matrix,
+                    octave_sparse_matrix, el_div);
+  INSTALL_BINOP_TI (ti, op_el_pow, octave_sparse_complex_matrix,
+                    octave_sparse_matrix, el_pow);
+  INSTALL_BINOP_TI (ti, op_el_ldiv, octave_sparse_complex_matrix,
+                    octave_sparse_matrix, el_ldiv);
+  INSTALL_BINOP_TI (ti, op_el_and, octave_sparse_complex_matrix,
+                    octave_sparse_matrix, el_and);
+  INSTALL_BINOP_TI (ti, op_el_or, octave_sparse_complex_matrix,
+                    octave_sparse_matrix, el_or);
 
-  INSTALL_CATOP (octave_sparse_complex_matrix, octave_sparse_matrix, scm_sm);
+  INSTALL_CATOP_TI (ti, octave_sparse_complex_matrix, octave_sparse_matrix,
+                    scm_sm);
 
-  INSTALL_ASSIGNOP (op_asn_eq, octave_sparse_complex_matrix,
-                    octave_sparse_matrix, assign);
+  INSTALL_ASSIGNOP_TI (ti, op_asn_eq, octave_sparse_complex_matrix,
+                       octave_sparse_matrix, assign);
 }
-
