@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2004-2018 David Bateman
+Copyright (C) 2004-2019 David Bateman
 Copyright (C) 1998-2004 Andy Adler
 Copyright (C) 2010 VZLU Prague
 
@@ -68,20 +68,22 @@ protected:
     octave::refcount<int> count;
 
     SparseRep (void)
-      : d (nullptr), r (nullptr), c (new octave_idx_type [1] {}),
-        nzmx (0), nrows (0), ncols (0), count (1)
+      : d (new T [1]), r (new octave_idx_type [1] {}),
+        c (new octave_idx_type [1] {}),
+        nzmx (1), nrows (0), ncols (0), count (1)
     { }
 
     SparseRep (octave_idx_type n)
-      : d (nullptr), r (nullptr), c (new octave_idx_type [n+1] {}),
-        nzmx (0), nrows (n), ncols (n), count (1)
+      : d (new T [1]), r (new octave_idx_type [1] {}),
+        c (new octave_idx_type [n+1] {}),
+        nzmx (1), nrows (n), ncols (n), count (1)
     { }
 
-    SparseRep (octave_idx_type nr, octave_idx_type nc, octave_idx_type nz = 0)
-      : d (nz > 0 ? new T [nz] : nullptr),
-        r (nz > 0 ? new octave_idx_type [nz] {} : nullptr),
-        c (new octave_idx_type [nc+1] {}), nzmx (nz), nrows (nr),
-        ncols (nc), count (1)
+    SparseRep (octave_idx_type nr, octave_idx_type nc, octave_idx_type nz = 1)
+      : d (nz > 0 ? new T [nz] : new T [1]),
+        r (nz > 0 ? new octave_idx_type [nz] {} : new octave_idx_type [1] {}),
+        c (new octave_idx_type [nc+1] {}),
+        nzmx (nz > 0 ? nz : 1), nrows (nr), ncols (nc), count (1)
     { }
 
     SparseRep (const SparseRep& a)
@@ -475,7 +477,7 @@ public:
   bool is_square (void) const
   { return issquare (); }
 
-  bool isempty (void) const { return (rows () < 1 && cols () < 1); }
+  bool isempty (void) const { return (rows () < 1 || cols () < 1); }
 
   OCTAVE_DEPRECATED (4.4, "use 'isempty' instead")
   bool is_empty (void) const
