@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 1996-2017 John W. Eaton
+Copyright (C) 1996-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -27,8 +27,9 @@ along with Octave; see the file COPYING.  If not, see
 #include <cctype>
 #include <cstdlib>
 
-#include <iostream>
+#include <istream>
 #include <limits>
+#include <ostream>
 #include <vector>
 
 #include "byte-swap.h"
@@ -37,6 +38,11 @@ along with Octave; see the file COPYING.  If not, see
 #include "lo-ieee.h"
 #include "oct-locbuf.h"
 
+// FIXME: Almost all platform-dependent sizes such as "short" are now defined
+// to take fixed values (such as 2B).  This was instigated for Matlab
+// compatibility (bug #41672).  It means a lot of this code is probably
+// obsolete and could be pared down or removed entirely.
+
 #if defined (OCTAVE_HAVE_LONG_LONG_INT)
 #  define FIND_SIZED_INT_TYPE(VAL, BITS, TQ, Q)                         \
   do                                                                    \
@@ -135,7 +141,7 @@ strip_spaces (const std::string& str)
 
   size_t k = 0;
 
-  std::string s (n, ' ');
+  std::string s (n, '\0');
 
   for (size_t i = 0; i < n; i++)
     if (! isspace (str[i]))
@@ -272,7 +278,8 @@ oct_data_conv::data_type_size (data_type dt)
 
     case oct_data_conv::dt_unknown:
     default:
-      abort ();
+      (*current_liboctave_error_handler)
+        ("oct_data_conv::data_type_size: unknown data type");
       break;
     }
 
@@ -297,10 +304,23 @@ oct_data_conv::string_to_data_type (const std::string& str)
 
   std::string s = strip_spaces (str);
 
-  if (s == "int8" || s == "integer*1")
-    retval = dt_int8;
-  else if (s == "uint8")
+  // Organized so most frequent precision appears first
+  if (s == "uint8")
     retval = dt_uint8;
+  else if (s == "double" || s == "float64" || s == "real*8")
+    retval = dt_double;
+  else if (s == "single" || s == "float" || s == "float32" || s == "real*4")
+    retval = dt_single;
+  else if (s == "char" || s == "char*1")
+    retval = dt_char;
+  else if (s == "int")
+    retval = dt_int32;
+  else if (s == "uchar" || s == "unsignedchar")
+    retval = dt_uint8;
+  else if (s == "schar" || s == "signedchar")
+    retval = dt_int8;
+  else if (s == "int8" || s == "integer*1")
+    retval = dt_int8;
   else if (s == "int16" || s == "integer*2")
     retval = dt_int16;
   else if (s == "uint16")
@@ -313,39 +333,21 @@ oct_data_conv::string_to_data_type (const std::string& str)
     retval = dt_int64;
   else if (s == "uint64")
     retval = dt_uint64;
-  else if (s == "single" || s == "float32" || s == "real*4")
-    retval = dt_single;
-  else if (s == "double" || s == "float64" || s == "real*8")
-    retval = dt_double;
-  else if (s == "char" || s == "char*1")
-    retval = dt_char;
-  else if (s == "schar" || s == "signedchar")
-    retval = dt_schar;
-  else if (s == "uchar" || s == "unsignedchar")
-    retval = dt_uchar;
   else if (s == "short")
-    GET_SIZED_INT_TYPE (short, );
+    retval = dt_int16;
   else if (s == "ushort" || s == "unsignedshort")
-    GET_SIZED_INT_TYPE (unsigned short, u);
-  else if (s == "int")
-    GET_SIZED_INT_TYPE (int, );
+    retval = dt_uint16;
   else if (s == "uint" || s == "unsignedint")
-    GET_SIZED_INT_TYPE (unsigned int, u);
+    retval = dt_uint32;
   else if (s == "long")
-    GET_SIZED_INT_TYPE (long, );
+    retval = dt_int32;
   else if (s == "ulong" || s == "unsignedlong")
-    GET_SIZED_INT_TYPE (unsigned long, u);
+    retval = dt_uint32;
+  // FIXME: The following are undocumented precisions
   else if (s == "longlong")
     GET_SIZED_INT_TYPE (long long, );
   else if (s == "ulonglong" || s == "unsignedlonglong")
     GET_SIZED_INT_TYPE (unsigned long long, u);
-  else if (s == "float")
-    {
-      if (sizeof (float) == sizeof (double))
-        retval = dt_double;
-      else
-        retval = dt_single;
-    }
   else if (s == "logical")
     retval = dt_logical;
   else
