@@ -1,32 +1,32 @@
 /*
 
-Copyright (C) 1996-2015 John W. Eaton
+Copyright (C) 1996-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
-#if !defined (octave_data_conv_h)
+#if ! defined (octave_data_conv_h)
 #define octave_data_conv_h 1
 
-#include <limits>
+#include "octave-config.h"
 
 #include "mach-info.h"
-#include "oct-inttypes.h"
+#include "oct-inttypes-fwd.h"
 
 class
 OCTAVE_API
@@ -96,25 +96,25 @@ enum save_type
 
 extern OCTAVE_API void
 do_double_format_conversion (void *data, octave_idx_type len,
-                             oct_mach_info::float_format from_fmt,
-                             oct_mach_info::float_format to_fmt
-                             = oct_mach_info::native_float_format ());
+                             octave::mach_info::float_format from_fmt,
+                             octave::mach_info::float_format to_fmt
+                             = octave::mach_info::native_float_format ());
 
 extern OCTAVE_API void
 do_float_format_conversion (void *data, octave_idx_type len,
-                            oct_mach_info::float_format from_fmt,
-                            oct_mach_info::float_format to_fmt
-                            = oct_mach_info::native_float_format ());
+                            octave::mach_info::float_format from_fmt,
+                            octave::mach_info::float_format to_fmt
+                            = octave::mach_info::native_float_format ());
 
 extern OCTAVE_API void
 do_float_format_conversion (void *data, size_t sz, octave_idx_type len,
-                            oct_mach_info::float_format from_fmt,
-                            oct_mach_info::float_format to_fmt
-                            = oct_mach_info::native_float_format ());
+                            octave::mach_info::float_format from_fmt,
+                            octave::mach_info::float_format to_fmt
+                            = octave::mach_info::native_float_format ());
 
 extern OCTAVE_API void
 read_doubles (std::istream& is, double *data, save_type type,
-              octave_idx_type len, bool swap, oct_mach_info::float_format fmt);
+              octave_idx_type len, bool swap, octave::mach_info::float_format fmt);
 
 extern OCTAVE_API void
 write_doubles (std::ostream& os, const double *data, save_type type,
@@ -122,7 +122,7 @@ write_doubles (std::ostream& os, const double *data, save_type type,
 
 extern OCTAVE_API void
 read_floats (std::istream& is, float *data, save_type type,
-             octave_idx_type len, bool swap, oct_mach_info::float_format fmt);
+             octave_idx_type len, bool swap, octave::mach_info::float_format fmt);
 
 extern OCTAVE_API void
 write_floats (std::ostream& os, const float *data, save_type type,
