@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2016-2018 John W. Eaton
+Copyright (C) 2016-2019 John W. Eaton
 
 This file is part of Octave.
 
@@ -54,11 +54,16 @@ octave_set_default_fpucw (void)
     SET_FPUCW (_FPU_DEFAULT);
 }
 
-// OLDCW is the name used by the fpucw.h macros.
+// OLDCW is the name used by the fpucw.h macros and gnulib doesn't give
+// us a choice.  We are also assuming that fpucw_t is unsigned, and no
+// wider than an int.
 
 unsigned int
 octave_begin_long_double_rounding (void)
 {
+  // Don't use DECL_LONG_DOUBLE_ROUNDING here because on some systems,
+  // it is defined to be empty.
+
   fpucw_t oldcw = 0;
 
   BEGIN_LONG_DOUBLE_ROUNDING ();
@@ -70,4 +75,7 @@ void
 octave_end_long_double_rounding (unsigned int oldcw)
 {
   END_LONG_DOUBLE_ROUNDING ();
+
+  // It might be unused.
+  octave_unused_parameter (oldcw);
 }
