@@ -1,22 +1,22 @@
 /*
 
-Copyright (C) 2016-2017 John W. Eaton
+Copyright (C) 2016-2019 John W. Eaton
 
 This file is part of Octave.
 
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
+Octave is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
+Octave is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
+<https://www.gnu.org/licenses/>.
 
 */
 
@@ -42,15 +42,7 @@ octave_uname_wrapper (char **sysname, char **nodename,
 
   int err = uname (&unm);
 
-  if (err == 0)
-    {
-      *sysname = unm.sysname;
-      *nodename = unm.nodename;
-      *release = unm.release;
-      *version = unm.version;
-      *machine = unm.machine;
-    }
-  else
+  if (err < 0)
     {
       *sysname = 0;
       *nodename = 0;
@@ -58,6 +50,14 @@ octave_uname_wrapper (char **sysname, char **nodename,
       *version = 0;
       *machine = 0;
     }
+  else
+    {
+      *sysname = unm.sysname;
+      *nodename = unm.nodename;
+      *release = unm.release;
+      *version = unm.version;
+      *machine = unm.machine;
+    }
 
   return err;
 }
