@@ -1,20 +1,20 @@
-## Copyright (C) 2001-2017 Paul Kienzle
+## Copyright (C) 2001-2019 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} interpft (@var{x}, @var{n})
@@ -40,7 +40,7 @@
 ## 2002-03-17 aadler
 ##    * added code to work on matrices as well
 ## 2006-05-25 dbateman
-##    * Make it matlab compatiable, cutting out the 2-D interpolation
+##    * Make it matlab compatible, cutting out the 2-D interpolation
 
 function z = interpft (x, n, dim)
 
@@ -118,21 +118,28 @@ endfunction
 
 %!shared n,y
 %! x = [0:10]';  y = sin(x);  n = length (x);
-%!assert (interpft (y, n), y, 20*eps)
-%!assert (interpft (y', n), y', 20*eps)
-%!assert (interpft ([y,y],n), [y,y], 20*eps)
+%!testif HAVE_FFTW
+%! assert (interpft (y, n), y, 20*eps)
+%!testif HAVE_FFTW
+%! assert (interpft (y', n), y', 20*eps)
+%!testif HAVE_FFTW
+%! assert (interpft ([y,y],n), [y,y], 20*eps)
 
 ## Test case with complex input
-%!test <39566>
+%!testif HAVE_FFTW <*39566>
 %! x = (1 + j) * [1:4]';
 %! y = ifft ([15 + 15*j; -6; -1.5 - 1.5*j; 0; -1.5 - 1.5*j; -6*j]);
 %! assert (interpft (x, 6), y, 10*eps);
 
 ## Test for correct spectral symmetry with even/odd lengths
-%!assert (max (abs (imag (interpft ([1:8], 20)))), 0, 20*eps)
-%!assert (max (abs (imag (interpft ([1:8], 21)))), 0, 21*eps)
-%!assert (max (abs (imag (interpft ([1:9], 20)))), 0, 20*eps)
-%!assert (max (abs (imag (interpft ([1:9], 21)))), 0, 21*eps)
+%!testif HAVE_FFTW
+%! assert (max (abs (imag (interpft ([1:8], 20)))), 0, 20*eps)
+%!testif HAVE_FFTW
+%! assert (max (abs (imag (interpft ([1:8], 21)))), 0, 21*eps)
+%!testif HAVE_FFTW
+%! assert (max (abs (imag (interpft ([1:9], 20)))), 0, 20*eps)
+%!testif HAVE_FFTW
+%! assert (max (abs (imag (interpft ([1:9], 21)))), 0, 21*eps)
 
 ## Test input validation
 %!error interpft ()
