@@ -1,27 +1,27 @@
-## Copyright (C) 2000-2016 Kai Habel
+## Copyright (C) 2000-2019 Kai Habel
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {[@var{x}, @var{y}] =} pol2cart (@var{theta}, @var{r})
-## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} pol2cart (@var{theta}, @var{r}, @var{z})
-## @deftypefnx {Function File} {[@var{x}, @var{y}] =} pol2cart (@var{P})
-## @deftypefnx {Function File} {[@var{x}, @var{y}, @var{z}] =} pol2cart (@var{P})
-## @deftypefnx {Function File} {@var{C} =} pol2cart (@dots{})
+## @deftypefn  {} {[@var{x}, @var{y}] =} pol2cart (@var{theta}, @var{r})
+## @deftypefnx {} {[@var{x}, @var{y}, @var{z}] =} pol2cart (@var{theta}, @var{r}, @var{z})
+## @deftypefnx {} {[@var{x}, @var{y}] =} pol2cart (@var{P})
+## @deftypefnx {} {[@var{x}, @var{y}, @var{z}] =} pol2cart (@var{P})
+## @deftypefnx {} {@var{C} =} pol2cart (@dots{})
 ## Transform polar or cylindrical coordinates to Cartesian coordinates.
 ##
 ## The inputs @var{theta}, @var{r}, (and @var{z}) must be the same shape, or
@@ -59,15 +59,19 @@ function [x, y, z] = pol2cart (theta, r, z = [])
     r = theta(:,2);
     theta = theta(:,1);
   elseif (nargin == 2)
-    if (! ((isnumeric (theta) && isnumeric (r))
-            && (size_equal (theta, r) || isscalar (theta) || isscalar (r))))
+    if (! isnumeric (theta) || ! isnumeric (r))
+      error ("pol2cart: THETA, R must be numeric arrays of the same size, or scalar");
+    endif
+    [err, theta, r] = common_size (theta, r);
+    if (err)
       error ("pol2cart: THETA, R must be numeric arrays of the same size, or scalar");
     endif
   elseif (nargin == 3)
-    if (! ((isnumeric (theta) && isnumeric (r) && isnumeric (z))
-            && (size_equal (theta, r) || isscalar (theta) || isscalar (r))
-            && (size_equal (theta, z) || isscalar (theta) || isscalar (z))
-            && (size_equal (r, z) || isscalar (r) || isscalar (z))))
+    if (! isnumeric (theta) || ! isnumeric (r) || ! isnumeric (z))
+      error ("pol2cart: THETA, R, Z must be numeric arrays of the same size, or scalar");
+    endif
+    [err, theta, r, z] = common_size (theta, r, z);
+    if (err)
       error ("pol2cart: THETA, R, Z must be numeric arrays of the same size, or scalar");
     endif
   endif
@@ -76,7 +80,11 @@ function [x, y, z] = pol2cart (theta, r, z = [])
   y = r .* sin (theta);
 
   if (nargout <= 1)
-    x = [x(:), y(:), z(:)];
+    if (isempty (z))
+      x = [x(:), y(:)];
+    else
+      x = [x(:), y(:), z(:)];
+    endif
   endif
 
 endfunction
@@ -103,7 +111,7 @@ endfunction
 %! [x, y, z2] = pol2cart (t, r, z);
 %! assert (x, [0, 1, 2], sqrt (eps));
 %! assert (y, [0, 1, 2], sqrt (eps));
-%! assert (z, z2);
+%! assert (z2, z);
 
 %!test
 %! t = 0;
@@ -112,7 +120,7 @@ endfunction
 %! [x, y, z2] = pol2cart (t, r, z);
 %! assert (x, [0, 1, 2], sqrt (eps));
 %! assert (y, [0, 0, 0], sqrt (eps));
-%! assert (z, z2);
+%! assert (z2, z);
 
 %!test
 %! t = [1, 1, 1]*pi/4;
@@ -121,7 +129,7 @@ endfunction
 %! [x, y, z2] = pol2cart (t, r, z);
 %! assert (x, [1, 1, 1] / sqrt (2), eps);
 %! assert (y, [1, 1, 1] / sqrt (2), eps);
-%! assert (z, z2);
+%! assert (z2, z);
 
 %!test
 %! t = 0;
@@ -130,7 +138,7 @@ endfunction
 %! [x, y, z2] = pol2cart (t, r, z);
 %! assert (x, [1, 2, 3], eps);
 %! assert (y, [0, 0, 0] / sqrt (2), eps);
-%! assert (z, z2);
+%! assert (z2, [1, 1, 1]);
 
 %!test
 %! P = [0, 0; pi/4, sqrt(2); pi/4, 2*sqrt(2)];
