@@ -1,20 +1,20 @@
-## Copyright (C) 2007-2017 David Bateman
+## Copyright (C) 2007-2019 David Bateman
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} run @var{script}
@@ -33,7 +33,7 @@
 ## Implementation Note: If @var{script} includes a path component, then
 ## @code{run} first changes the working directory to the directory where
 ## @var{script} is found.  Next, the script is executed.  Finally, @code{run}
-## returns to the original working directory unless @code{script} has
+## returns to the original working directory unless @var{script} has
 ## specifically changed directories.
 ## @seealso{path, addpath, source}
 ## @end deftypefn
@@ -59,7 +59,7 @@ function run (script)
   endif
 
   if (! isempty (d))
-    if (! exist (d, "dir"))
+    if (! isfolder (d))
       error ("run: the path %s doesn't exist", d);
     endif
 
@@ -90,6 +90,53 @@ function run (script)
 endfunction
 
 
+## Test script file execution
+## Use a variable name that is unlikely to be the name of a function.
+%!test
+%! clear _5yVNhWVJWJn47RKnzxPsyb_
+%! assert (exist ("_5yVNhWVJWJn47RKnzxPsyb_"), 0);
+%! tmp_dir = tempname ();
+%! test_script = fullfile (tmp_dir, "test_script.m");
+%! unwind_protect
+%!   mkdir (tmp_dir);
+%!   fid = fopen (test_script, "w");
+%!   fprintf (fid, "_5yVNhWVJWJn47RKnzxPsyb_ = 1337;\n");
+%!   fclose (fid);
+%!   run (test_script);
+%!   assert (exist ("_5yVNhWVJWJn47RKnzxPsyb_", "var"), 1);
+%!   assert (_5yVNhWVJWJn47RKnzxPsyb_, 1337);
+%! unwind_protect_cleanup
+%!   unlink (test_script);
+%!   rmdir (tmp_dir);
+%! end_unwind_protect
+
+## Test function file execution
+%!test
+%! path_orig = path ();
+%! tmp_dir = tempname ();
+%! test_function = fullfile (tmp_dir, "tf.m");
+%! unwind_protect
+%!   mkdir (tmp_dir);
+%!   fid = fopen (test_function, "w");
+%!   fprintf (fid, "function tf ()\n");
+%!   fprintf (fid, "  addpath ('%s');\n", tmp_dir);
+%!   fprintf (fid, "endfunction\n");
+%!   fclose (fid);
+%!   ## Check if temporary directory is on the loadpath.
+%!   ## Function 'dir_in_loadpath' is broken for this use case, so code a test.
+%!   dirs = strsplit (path (), pathsep ());
+%!   tstval1 = any (strcmp (tmp_dir, dirs));
+%!   run (test_function);
+%!   dirs = strsplit (path (), pathsep ());
+%!   tstval2 = any (strcmp (tmp_dir, dirs));
+%!   assert (tstval1, false);
+%!   assert (tstval2, true);
+%! unwind_protect_cleanup
+%!   unlink (test_function);
+%!   rmdir (tmp_dir);
+%!   path (path_orig);
+%! end_unwind_protect
+
 ## Test input validation
 %!error run ()
 %!error run ("a", "b")
