@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2018 Søren Hauberg
+## Copyright (C) 2005-2019 Søren Hauberg
 ##
 ## This file is part of Octave.
 ##
@@ -19,6 +19,7 @@
 ## -*- texinfo -*-
 ## @deftypefn  {} {} untar (@var{tarfile})
 ## @deftypefnx {} {} untar (@var{tarfile}, @var{dir})
+## @deftypefnx {} {@var{filelist} =} untar (@dots{})
 ## Unpack the TAR archive @var{tarfile}.
 ##
 ## If @var{dir} is specified the files are unpacked in this directory rather
@@ -42,9 +43,9 @@ function filelist = untar (tarfile, dir = [])
   endif
 
   if (nargout > 0)
-    filelist = unpack (tarfile, dir, "untar");
+    filelist = unpack (tarfile, dir, "tar");
   else
-    unpack (tarfile, dir, "untar");
+    unpack (tarfile, dir, "tar");
   endif
 
 endfunction
