@@ -1,20 +1,20 @@
-## Copyright (C) 2007-2017 John W. Eaton
+## Copyright (C) 2007-2019 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} text (@var{x}, @var{y}, @var{string})
@@ -33,6 +33,9 @@
 ##
 ## The optional return value @var{h} is a vector of graphics handles to the
 ## created text objects.
+##
+## Programming Note: The full list of properties is documented at
+## @ref{Text Properties,,Text Properties}.
 ## @seealso{gtext, title, xlabel, ylabel, zlabel}
 ## @end deftypefn
 
@@ -68,64 +71,10 @@ function h = text (varargin)
       error ("text: number of X, Y, and Z coordinates must match");
     endif
 
-    if (ischar (string))
-
-      do_keyword_repl = true;
-      nt = rows (string);
-      if (nx == 1 && (nt == 1 || nt == 0))
-        ## Single text object with one line or empty line
-        string = {string};
-        nt = 1;
-      elseif (nx == 1 && nt > 1)
-        ## Single text object with multiple lines
-        ## FIXME: "default" or "factory" as first row
-        ##        should be escaped to "\default" or "\factory"
-        ##        Other rows do not require escaping.
-        do_keyword_repl = false;
-        string = {string};
-      elseif (nx > 1 && nt == nx)
-        ## Multiple text objects with different strings
-        string = cellstr (string);
-      elseif (nx > 1 && nt == 1)
-        ## Multiple text objects with same string
-        string = repmat ({string}, [nx, 1]);
-        nt = nx;
-      else
-        error ("text: Invalid combination of points and text strings");
-      endif
-
-      ## Escape special keywords
-      if (do_keyword_repl)
-        string = regexprep (string, '^(default|factory)$', '\\$1');
-      endif
-
-    elseif (iscell (string))
-
-      nt = numel (string);
-      if (nx == 1)
-        ## Single text object with one or more lines
-        string = {cellstr(string)};
-        nt = 1;
-      elseif (nx > 1 && nt == nx)
-        ## Multiple text objects with different strings
-      elseif (nx > 1 && nt == 1)
-        ## Multiple text objects with same string
-        string = repmat ({cellstr(string)}, [nx, 1]);
-        nt = nx;
-      else
-        error ("text: Invalid combination of points and text strings");
-      endif
-
-    else
-
-      error ("text: STRING must be a character string or cell array of character strings");
-
-    endif
   else  # Only PROP/VALUE pairs
     x = y = z = 0;
     nx = ny = nz = 1;
-    string = {""};
-    nt = 1;
+    string = "";
   endif
 
   ## Any remaining inputs must occur as PROPERTY/VALUE pairs
@@ -133,15 +82,17 @@ function h = text (varargin)
     print_usage ();
   endif
 
-  ## Get axis argument which may be in a 'parent' PROP/VAL pair
+  ## Get axis argument which may be in a "parent" PROP/VAL pair
   [hax, varargin] = __plt_get_axis_arg__ ("text", varargin{:});
-  if (isempty (hax))
-    hax = gca ();
-  else
-    hax = hax(1);
+
+  ## String argument may be in PROP/VAL pair
+  idx = find (strcmpi (varargin, "string"), 1);
+  if (idx)
+    string = varargin{idx+1};
+    varargin(idx:idx+1) = [];
   endif
 
-  ## Position argument may alse be in PROP/VAL pair
+  ## Position argument may be in PROP/VAL pair
   idx = find (strcmpi (varargin, "position"), 1);
   if (idx)
     pos = varargin{idx+1};
@@ -150,18 +101,78 @@ function h = text (varargin)
     pos = [x(:), y(:), z(:)];
   endif
 
+  ## Validate string argument
+  if (ischar (string))
+
+    do_keyword_repl = true;
+    nt = rows (string);
+    if (nx == 1 && (nt == 1 || nt == 0))
+      ## Single text object with one line or empty line
+      string = {string};
+      nt = 1;
+    elseif (nx == 1 && nt > 1)
+      ## Single text object with multiple lines
+      ## FIXME: "default" or "factory" as first row
+      ##        should be escaped to "\default" or "\factory"
+      ##        Other rows do not require escaping.
+      do_keyword_repl = false;
+      string = {string};
+    elseif (nx > 1 && nt == nx)
+      ## Multiple text objects with different strings
+      string = cellstr (string);
+    elseif (nx > 1 && nt == 1)
+      ## Multiple text objects with same string
+      string = repmat ({string}, [nx, 1]);
+      nt = nx;
+    else
+      error ("text: Invalid combination of points and text strings");
+    endif
+
+    ## Escape special keywords
+    if (do_keyword_repl)
+      string = regexprep (string, '^(default|factory)$', '\\$1');
+    endif
+
+  elseif (iscell (string))
+
+    nt = numel (string);
+    if (nx == 1)
+      ## Single text object with one or more lines
+      string = {cellstr(string)};
+      nt = 1;
+    elseif (nx > 1 && nt == nx)
+      ## Multiple text objects with different strings
+    elseif (nx > 1 && nt == 1)
+      ## Multiple text objects with same string
+      string = repmat ({cellstr(string)}, [nx, 1]);
+      nt = nx;
+    else
+      error ("text: Invalid combination of points and text strings");
+    endif
+
+  else
+
+    error ("text: STRING must be a character string or cell array of character strings");
+
+  endif
+
+  ## Select the correct axes
+  if (isempty (hax))
+    hax = gca ();
+  else
+    hax = hax(1);
+  endif
+
   ## Call __go_text__ to do the work
   htmp = zeros (nt, 1);
   if (nx == 1)
-    htmp = __go_text__ (hax, "string", string{1},
-                             ## varargin first, in case "Units" set for pos.
-                             varargin{:},
-                             "position", pos);
+    ## Set varargin first, in case it changes units or interpreter properties.
+    htmp = __go_text__ (hax, varargin{:}, "position", pos,
+                             "string", string{1});
   else
     for n = 1:nt
-      htmp(n) = __go_text__ (hax, "string", string{n},
-                                  varargin{:},
-                                  "position", pos(n,:));
+      htmp(n) = __go_text__ (hax, varargin{:}, "position", pos(n,:),
+                                  "string", string{n});
     endfor
     __request_drawnow__ ();
   endif
@@ -203,10 +214,15 @@ endfunction
 %! h = mesh (peaks, "edgecolor", 0.7 * [1 1 1], ...
 %!                  "facecolor", "none", ...
 %!                  "facealpha", 0);
+%! colors = jet (9);
+%! ii = 1;
 %! for t = 0:45:359;
+%!   ii = ii +1;
 %!   text (25, 25, 0, "Vertical Alignment = Bottom", ...
 %!                    "rotation", t, ...
 %!                    "horizontalalignment", "left", ...
+%!                    "backgroundcolor", colors(ii,:), ...
+%!                    "edgecolor", "k", ...
 %!                    "verticalalignment", "bottom");
 %! endfor
 %! caxis ([-100 100]);
@@ -340,6 +356,25 @@ endfunction
 %!   close (hf);
 %! end_unwind_protect
 
+%!test <*54067>
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   ht = text ("String", "Hello", "Position", [0.5, 0.5], "FontSize", 16);
+%!   assert (get (ht, "String"), "Hello");
+%!   assert (get (ht, "FontSize"), 16);
+%! unwind_protect_cleanup
+%!   close (hf);
+%! end_unwind_protect
+
+%!test <*54109>
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   ht = text ();
+%!   assert (get (ht, "string"), "");
+%! unwind_protect_cleanup
+%!   close (hf);
+%! end_unwind_protect
+
 ## Test input validation
 %!error <X, Y, and Z coordinates must match> text (1, [2 3], "foobar")
 %!error <X, Y, and Z coordinates must match> text (1, 2, [3 4], "foobar")
