@@ -1,23 +1,23 @@
-## Copyright (C) 2007-2015 David Bateman
+## Copyright (C) 2007-2019 David Bateman
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{hg} =} __scatter__ (@dots{})
+## @deftypefn {} {@var{hg} =} __scatter__ (@dots{})
 ## Undocumented internal function.
 ## @end deftypefn
 
@@ -36,16 +36,60 @@ function hg = __scatter__ (varargin)
     istart = 7;
   endif
 
+  ## Force mixtures of int and float data to be float (Bug #4116).
+  if (xor (isfloat (x), isfloat (y)))
+    if (isfloat (x))
+      y = cast (y, class (x));
+    else
+      x = cast (x, class (y));
+    endif
+  endif
+  if (nd != 2)
+    if (xor (isfloat (x), isfloat (z)))
+      if (isfloat (x))
+        z = cast (z, class (x));
+      else
+        x = cast (x, class (z));
+        y = cast (y, class (z));
+      endif
+    endif
+  endif
+
   if (istart <= nargin)
     s = varargin{istart}(:);
     if (isempty (s) || ischar (s))
-      s = 6;
+      s = 36;
     endif
     if (! ischar (varargin{istart}))
-      istart++;
+      istart += 1;
     endif
   else
-    s = 6;
+    s = 36;
+  endif
+
+  firstnonnumeric = find (! cellfun ("isnumeric", varargin(istart:nargin)), 1);
+  if (isempty (firstnonnumeric))
+    firstnonnumeric = Inf;
+  else
+    firstnonnumeric += istart - 1;
+  endif
+
+  if (istart <= nargin && firstnonnumeric > istart)
+    c = varargin{istart};
+    if (isvector (c) && columns (c) != 3)
+      c = c(:);
+    endif
+  elseif (firstnonnumeric == istart && ischar (varargin{istart})
+          && any (tolower (varargin{istart}(1)) == "ymcrgbwk"))
+    [linespec, valid] = __pltopt__ (fcn, varargin{istart}, false);
+    if (valid)
+      c = varargin{istart};
+      firstnonnumeric += 1;
+    else
+      c = [];
+    endif
+  else
+    c = [];
   endif
 
   ## Remove NaNs
@@ -62,26 +106,8 @@ function hg = __scatter__ (varargin)
   if (numel (s) > 1)
     s(idx) = [];
   endif
-
-  firstnonnumeric = find (! cellfun ("isnumeric", varargin(istart:nargin)), 1);
-  if (isempty (firstnonnumeric))
-    firstnonnumeric = Inf;
-  else
-    firstnonnumeric += istart - 1;
-  endif
-
-  if (istart <= nargin && firstnonnumeric > istart)
-    c = varargin{istart};
-    if (isvector (c) && columns (c) != 3)
-      c = c(:);
-    endif
-  elseif (firstnonnumeric == istart && ischar (varargin{istart})
-          && ! (   strcmpi (varargin{istart}, "filled")
-                || strcmpi (varargin{istart}, "fill")))
-    c = varargin{istart};
-    firstnonnumeric++;
-  else
-    c = [];
+  if (rows (c) > 1)
+    c(idx,:) = [];
   endif
 
   ## Validate inputs
@@ -111,18 +137,24 @@ function hg = __scatter__ (varargin)
     elseif ((ischar (arg) || iscellstr (arg)) && ! have_marker)
       [linespec, valid] = __pltopt__ (fcn, arg, false);
       if (valid)
+        ## Valid linestyle, but possibly not valid marker
         have_marker = true;
         marker = linespec.marker;
         if (strcmp (marker, "none"))
           marker = "o";
         elseif (isempty (marker))
           have_marker = false;
-          [~, marker] = __next_line_style__ ();
+          marker = "o";
         endif
       else
-        error ("%s: invalid linespec", fcn);
+        ## Prop/Val pair
+        newargs{end+1} = arg;
+        if (iarg <= nargin)
+          newargs{end+1} = varargin{iarg++};
+        endif
       endif
     else
+      ## Prop/Val pair
       newargs{end+1} = arg;
       if (iarg <= nargin)
         newargs{end+1} = varargin{iarg++};
@@ -156,6 +188,7 @@ function hg = __scatter__ (varargin)
   addlistener (hg, "sizedata", @update_data);
 
   one_explicit_color = ischar (c) || isequal (size (c), [1, 3]);
+  s = sqrt (s);  # size adjustment for visual compatibility w/Matlab
 
   if (numel (x) <= 100)
 
@@ -168,16 +201,16 @@ function hg = __scatter__ (varargin)
     if (one_explicit_color)
       for i = 1 : numel (x)
         if (filled)
-          __go_patch__ (hg, "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
+          __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                        "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
                         "faces", 1, "vertices", [x(i), y(i), z(i,:)],
-                        "facecolor", "none", "edgecolor", "none",
                         "marker", marker,  "markersize", s(i),
                         "markeredgecolor", c, "markerfacecolor", c,
                         "linestyle", "none");
         else
-          __go_patch__ (hg, "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
+          __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                        "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
                         "faces", 1, "vertices", [x(i), y(i), z(i,:)],
-                        "facecolor", "none", "edgecolor", "none",
                         "marker", marker,  "markersize", s(i),
                         "markeredgecolor", c, "markerfacecolor", "none",
                         "linestyle", "none");
@@ -189,18 +222,18 @@ function hg = __scatter__ (varargin)
       endif
       for i = 1 : numel (x)
         if (filled)
-          __go_patch__ (hg, "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
+          __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                        "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
                         "faces", 1, "vertices", [x(i), y(i), z(i,:)],
-                        "facecolor", "none", "edgecolor", "none",
                         "marker", marker, "markersize", s(i),
                         "markeredgecolor", "none",
                         "markerfacecolor", "flat",
                         "cdata", c(i,:), "facevertexcdata", c(i,:),
                         "linestyle", "none");
         else
-          __go_patch__ (hg, "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
+          __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                        "xdata", x(i), "ydata", y(i), "zdata", z(i,:),
                         "faces", 1, "vertices", [x(i), y(i), z(i,:)],
-                        "facecolor", "none", "edgecolor", "none",
                         "marker", marker, "markersize", s(i),
                         "markeredgecolor", "flat",
                         "markerfacecolor", "none",
@@ -284,29 +317,32 @@ function hg = __scatter__ (varargin)
 endfunction
 
 function render_size_color (hg, vert, s, c, marker, filled, isflat)
+
   if (isscalar (s))
     x = vert(:,1);
     y = vert(:,2);
     z = vert(:,3:end);
     toolkit = get (ancestor (hg, "figure"), "__graphics_toolkit__");
     ## Does gnuplot only support triangles with different vertex colors ?
-    ## TODO: Verify gnuplot can only support one color.  If RGB triplets
-    ##       can be assigned to each vertex, then fix __go_draw_axes__.m
+    ## FIXME: Verify gnuplot can only support one color.  If RGB triplets
+    ##        can be assigned to each vertex, then fix __gnuplot_draw_axes__.m
     gnuplot_hack = (numel (x) > 1 && columns (c) == 3
                     && strcmp (toolkit, "gnuplot"));
     if (ischar (c) || ! isflat || gnuplot_hack)
       if (filled)
-        __go_patch__ (hg, "xdata", x, "ydata", y, "zdata", z,
+        ## "facecolor" and "edgecolor" must be set before any other properties
+        ## to skip co-planarity check (see bug #55751).
+        __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                          "xdata", x, "ydata", y, "zdata", z,
                           "faces", 1:numel (x), "vertices", vert,
-                          "facecolor", "none", "edgecolor", "none",
                           "marker", marker,
                           "markeredgecolor", "none",
                           "markerfacecolor", c(1,:),
                           "markersize", s, "linestyle", "none");
       else
-        __go_patch__ (hg, "xdata", x, "ydata", y, "zdata", z,
+        __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                          "xdata", x, "ydata", y, "zdata", z,
                           "faces", 1:numel (x), "vertices", vert,
-                          "facecolor", "none", "edgecolor", "none",
                           "marker", marker,
                           "markeredgecolor", c(1,:),
                           "markerfacecolor", "none",
@@ -314,18 +350,18 @@ function render_size_color (hg, vert, s, c, marker, filled, isflat)
       endif
     else
       if (filled)
-        __go_patch__ (hg, "xdata", x, "ydata", y, "zdata", z,
+        __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                          "xdata", x, "ydata", y, "zdata", z,
                           "faces", 1:numel (x), "vertices", vert,
-                          "facecolor", "none", "edgecolor", "none",
                           "marker", marker, "markersize", s,
                           "markeredgecolor", "none",
                           "markerfacecolor", "flat",
                           "cdata", c, "facevertexcdata", c,
                           "linestyle", "none");
       else
-        __go_patch__ (hg, "xdata", x, "ydata", y, "zdata", z,
+        __go_patch__ (hg, "facecolor", "none", "edgecolor", "none",
+                          "xdata", x, "ydata", y, "zdata", z,
                           "faces", 1:numel (x), "vertices", vert,
-                          "facecolor", "none", "edgecolor", "none",
                           "marker", marker, "markersize", s,
                           "markeredgecolor", "flat",
                           "markerfacecolor", "none",
@@ -342,9 +378,11 @@ function render_size_color (hg, vert, s, c, marker, filled, isflat)
                              marker, filled, isflat);
     endfor
   endif
+
 endfunction
 
 function update_props (h, d)
+
   lw = get (h, "linewidth");
   m  = get (h, "marker");
   fc = get (h, "markerfacecolor");
@@ -353,37 +391,104 @@ function update_props (h, d)
 
   set (kids, "linewidth", lw, "marker", m,
              "markerfacecolor", fc, "markeredgecolor", ec);
+
 endfunction
 
+## FIXME: This callback routine doesn't handle the case where N > 100.
 function update_data (h, d)
+
   x = get (h, "xdata");
   y = get (h, "ydata");
   z = get (h, "zdata");
-  c = get (h, "cdata");
-  if (rows (c) == 1)
-    c = repmat (c, numel (x), 1);
+  if (numel (x) > 100)
+    error ("scatter: cannot update data with more than 100 points.  Call scatter (x, y, ...) with new data instead.");
   endif
+  c = get (h, "cdata");
+  one_explicit_color = ischar (c) || isequal (size (c), [1, 3]);
+  if (! one_explicit_color)
+    if (rows (c) == 1)
+      c = repmat (c, numel (x), 1);
+    endif
+  endif
+  filled = ! strcmp (get (h, "markerfacecolor"), "none");
   s = get (h, "sizedata");
+  ## Size adjustment for visual compatibility with Matlab.
+  s = sqrt (s);
   if (numel (s) == 1)
     s = repmat (s, numel (x), 1);
   endif
   hlist = get (h, "children");
 
-  if (isempty (z))
-    for i = 1 : length (hlist)
-      set (hlist(i), "vertices", [x(i), y(i)],
-                     "cdata", reshape (c(i,:),[1, size(c)(2:end)]),
-                     "facevertexcdata", c(i,:),
-                     "markersize", s(i));
-    endfor
+  if (one_explicit_color)
+    if (filled)
+      if (isempty (z))
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", c, "markerfacecolor", c);
+
+        endfor
+      else
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i), z(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", c, "markerfacecolor", c);
+        endfor
+      endif
+    else
+      if (isempty (z))
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", c, "markerfacecolor", "none");
+
+        endfor
+      else
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i), z(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", c, "markerfacecolor", "none");
+        endfor
+      endif
+    endif
   else
-    for i = 1 : length (hlist)
-      set (hlist(i), "vertices", [x(i), y(i), z(i)],
-                     "cdata", reshape (cd(i,:),[1, size(cd)(2:end)]),
-                     "facevertexcdata", cd(i,:),
-                     "markersize", s(i));
-    endfor
+    if (filled)
+      if (isempty (z))
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", "none", "markerfacecolor", "flat",
+                         "cdata", reshape (c(i,:),[1, size(c)(2:end)]),
+                         "facevertexcdata", c(i,:));
+        endfor
+      else
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i), z(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", "none", "markerfacecolor", "flat",
+                         "cdata", reshape (c(i,:),[1, size(c)(2:end)]),
+                         "facevertexcdata", c(i,:));
+        endfor
+      endif
+    else
+      if (isempty (z))
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", "flat", "markerfacecolor", "none",
+                         "cdata", reshape (c(i,:),[1, size(c)(2:end)]),
+                         "facevertexcdata", c(i,:));
+        endfor
+      else
+        for i = 1 : length (hlist)
+          set (hlist(i), "vertices", [x(i), y(i), z(i)],
+                         "markersize", s(i),
+                         "markeredgecolor", "flat", "markerfacecolor", "none",
+                         "cdata", reshape (c(i,:),[1, size(c)(2:end)]),
+                         "facevertexcdata", c(i,:));
+        endfor
+      endif
+    endif
   endif
 
 endfunction
-
