@@ -2,4 +2,4 @@ function n = numel (this)
 
   n = prod (this.desired_size);
 
-endfunction
+end
